@@ -24,13 +24,9 @@
 #include "item.h"
 #include "script.h"
 
-static item *free_items;        /* the list of free (unused) items */
 static item *player, *map;      /* these lists contains rest of items */
 /* player = pl->ob, map = pl->below */
 
-#define NROF_ITEMS 50           /* how many items are reserved initially */
-/* for the item spool */
-
 #include "item-types.h"
 
 /* This uses the item_types table above.  We try to figure out if
@@ -240,24 +236,6 @@ static item *new_item(void)
     return op;
 }
 
-/*
- *  alloc_items() returns pointer to list of allocated objects
- */
-static item *alloc_items(int nrof)
-{
-    item *op, *list;
-    int i;
-
-    list = op = new_item();
-
-    for (i = 1; i < nrof; i++) {
-        op->next = new_item();
-        op->next->prev = op;
-        op = op->next;
-    }
-    return list;
-}
-
 /*
  *  free_items() frees all allocated items from list
  */
@@ -357,34 +335,7 @@ void remove_item(item *op)
         return; /* Don't free this! */
     }
 
-    /* add object to a list of free objects */
-    op->next = free_items;
-    if (op->next != NULL) {
-        op->next->prev = op;
-    }
-    free_items = op;
-
-    /* Clear all these values, since this item will get re-used */
-    op->prev = NULL;
-    op->env = NULL;
-    op->tag = 0;
-    copy_name(op->d_name, "");
-    copy_name(op->s_name, "");
-    copy_name(op->p_name, "");
-    op->inv = NULL;
-    op->env = NULL;
-    op->tag = 0;
-    op->face = 0;
-    op->weight = 0;
-    op->magical = op->cursed = op->damned = op->blessed = 0;
-    op->unpaid = op->locked = op->applied = 0;
-    op->flagsval = 0;
-    op->animation_id = 0;
-    op->last_anim = 0;
-    op->anim_state = 0;
-    op->nrof = 0;
-    op->open = 0;
-    op->type = NO_ITEM_TYPE;
+    g_free(op);
 }
 
 /*
@@ -432,19 +383,10 @@ static void add_item(item *env, item *op)
  *  and sets its tag field and clears locked flag (all other fields
  *  are unitialized and may contain random values)
  */
-item *create_new_item(item *env, gint32 tag)
+static item *create_new_item(item *env, gint32 tag)
 {
     item *op;
-
-    if (!free_items) {
-        free_items = alloc_items(NROF_ITEMS);
-    }
-
-    op = free_items;
-    free_items = free_items->next;
-    if (free_items) {
-        free_items->prev = NULL;
-    }
+    op = new_item();
 
     op->tag = tag;
     op->locked = 0;
@@ -455,18 +397,6 @@ item *create_new_item(item *env, gint32 tag)
     return op;
 }
 
-int num_free_items(void)
-{
-    item *tmp;
-    int count = 0;
-
-    for (tmp = free_items; tmp; tmp = tmp->next) {
-        count++;
-    }
-
-    return count;
-}
-
 /*
  *  Hardcoded now, server could send these at initiation phase.
  */
@@ -506,6 +436,9 @@ static void set_flag_string(item *op)
     if (op->unpaid) {
         strcat(op->flags, " (unpaid)");
     }
+    if (op->read) {
+        strcat(op->flags, " (read)");
+    }
 }
 
 static void get_flags(item *op, guint16 flags)
@@ -519,6 +452,7 @@ static void get_flags(item *op, guint16 flags)
     op->unpaid   = flags&F_UNPAID  ? 1 : 0;
     op->applied  = flags&F_APPLIED ? 1 : 0;
     op->locked   = flags&F_LOCKED  ? 1 : 0;
+    op->read     = flags&F_READ    ? 1 : 0;
     op->flagsval = flags;
     op->apply_type = flags&F_APPLIED;
     set_flag_string(op);
@@ -602,7 +536,7 @@ void toggle_locked(item *op)
         return; /* if item is on the ground, don't lock it */
     }
 
-    snprintf((char*)buf, sizeof(buf), "lock %c %d", !op->locked, op->tag);
+    snprintf((char*)buf, sizeof(buf), "lock %d %d", !op->locked, op->tag);
     script_monitor_str((char*)buf);
     SockList_Init(&sl, buf);
     SockList_AddString(&sl, "lock ");
