@@ -35,6 +35,9 @@
 extern void config_check(void);
 extern void map_check_resize(void);
 
+/** If true, the next drawextinfo is expected to contain a map path. */
+bool arm_mapedit = false;
+
 /* TODO Help topics other than commands? Refer to other documents? */
 
 static int get_num_commands(void);
@@ -211,6 +214,11 @@ static void do_savedefaults() { save_defaults(); }
 
 static void do_savewinpos() { save_winpos(); }
 
+static void do_mapedit() {
+    send_command("mapinfo", -1, 1);
+    arm_mapedit = true;
+}
+
 static void do_set_mapscale(const char *used) {
     if (used != NULL) {
         long long scale = strtoll(used, NULL, 0);
@@ -295,6 +303,16 @@ static const char * help_scriptkill(void) {
         "(Not guaranteed to work?)";
 }
 
+static const char * help_scriptkillall(void) {
+    return
+        "Syntax:\n"
+        "\n"
+        "    scriptkillall\n"
+        "\n"
+        "Stop all active scripts.\n"
+        "(Not guaranteed to work?)";
+}
+
 static void cmd_raw(const char *cmd) {
     cs_print_string(csocket.fd, "%s", cmd);
 }
@@ -316,6 +334,8 @@ static ConsoleCommand CommonCommands[] = {
 
     {"scriptkill", COMM_CAT_SCRIPT, script_kill, help_scriptkill, NULL},
 
+    {"scriptkillall", COMM_CAT_SCRIPT, script_killall_wrapper, help_scriptkillall, NULL},
+
     {"scripttell", COMM_CAT_SCRIPT, script_tell, help_scripttell, NULL},
 
     {"clearinfo", COMM_CAT_MISC, do_clearinfo, NULL, "Clear message window"},
@@ -335,6 +355,8 @@ static ConsoleCommand CommonCommands[] = {
     {"magicmap", COMM_CAT_MISC, do_magicmap, help_magicmap,
      HELP_MAGICMAP_SHORT},
 
+    {"mapedit", COMM_CAT_MISC, do_mapedit, NULL, NULL},
+
     {"mapscale", COMM_CAT_MISC, do_set_mapscale, NULL, NULL},
 
     {"savedefaults", COMM_CAT_SETUP, do_savedefaults, NULL,
@@ -533,7 +555,7 @@ void extended_command(const char *ocommand) {
     /* If this isn't a client-side command, send it to the server. */
     if (!handle_local_command(cp, cpnext)) {
         /* just send the command(s)  (if `ocommand' is a compound command */
-        /* then split it and send each part seperately */
+        /* then split it and send each part separately */
         /* TODO Remove this from the server; end of commands.c. */
         strncpy(command, ocommand, MAX_BUF-1);
         command[MAX_BUF-1]=0;
