@@ -60,8 +60,6 @@ void free_all_items(item *op);
 item *locate_item(gint32 tag);
 void remove_item(item *op);
 void remove_item_inventory(item *op);
-item *create_new_item(item *env, gint32 tag);
-int num_free_items(void);
 void set_item_values(item *op, char *name, gint32 weight, guint16 face, guint16 flags, guint16 anim, guint16 animspeed, guint32 nrof, guint16 type);
 void toggle_locked(item *op);
 void send_mark_obj(item *op);
@@ -102,6 +100,7 @@ void clear_run(void);
 void fire_dir(int dir);
 void stop_run(void);
 void run_dir(int dir);
+void walk_dir(int dir);
 int send_command(const char *command, int repeat, int must_send);
 void CompleteCmd(unsigned char *data, int len);
 void command_take(const char *command, const char *cpnext);
