@@ -51,7 +51,7 @@ char* last_server;
 bool time_map_redraw = false;
 
 /** Speed of local map prediction scrolling, 0-100 (0 to disable). */
-int predict_alpha;
+int predict_alpha = 10;
 
 static void on_config_close(GtkButton *button, gpointer user_data);
 
@@ -456,9 +456,13 @@ void config_load() {
 
     /* Load configuration values into settings array. */
     if (error == NULL) {
+        LOG(LOG_DEBUG, "config_load", "config_path='%s'", config_path->str);
         for (int i = 1; i < CONFIG_NUMS; i++) {
-            want_config[i] = g_key_file_get_integer(config, "Client",
-                    config_names[i], NULL);
+            GError *error = NULL;
+            gint value = g_key_file_get_integer(config, "Client", config_names[i], &error);
+            if (error == NULL) {
+                want_config[i] = value;
+            }
         }
 
         /* Load additional settings. */
