@@ -1,47 +1,29 @@
-const char * const rcsid_gtk2_create_char_c =
-    "$Id: create_char.c 12988 2010-04-27 04:04:46Z kbulgrien $";
 /*
-    Crossfire client, a client program for the crossfire program.
-
-    Copyright (C) 2010,2011 Mark Wedel & Crossfire Development Team
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-    The author can be reached via e-mail to crossfire@metalforge.org
-*/
-
-/**
- * @file gtk-v2/src/create_char.c
- * Handles creation of new characters
+ * Crossfire -- cooperative multi-player graphical RPG and adventure game
+ *
+ * Copyright (c) 1999-2013 Mark Wedel and the Crossfire Development Team
+ * Copyright (c) 1992 Frank Tore Johansen
+ *
+ * Crossfire is free software and comes with ABSOLUTELY NO WARRANTY. You are
+ * welcome to redistribute it under certain conditions. For details, see the
+ * 'LICENSE' and 'COPYING' files.
+ *
+ * The authors can be reached via e-mail to crossfire-devel@real-time.com
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
-#include <gtk/gtk.h>
-#include <glade/glade.h>
-#include <ctype.h>
+/**
+ * @file
+ * Handle new character creation
+ */
 
 #include "client.h"
 
-#include "image.h"
+#include <gtk/gtk.h>
 
+#include "image.h"
 #include "main.h"
-#include "gtk2proto.h"
 #include "metaserver.h"
+#include "gtk2proto.h"
 
 /* This corresponds to the number of opt_.. fields in the
  * create_character_window.  In theory, the vbox could be resized
@@ -67,17 +49,17 @@ const char * const rcsid_gtk2_create_char_c =
 
 /* These are in the create_character_window */
 static GtkWidget *spinbutton_cc[NUM_NEW_CHAR_STATS], *label_rs[NUM_NEW_CHAR_STATS],
-    *label_cs[NUM_NEW_CHAR_STATS], *label_tot[NUM_NEW_CHAR_STATS],
-    *label_cc_unspent, *textview_rs_desc, *label_cc_desc, *label_cc_status_update,
-    *button_cc_cancel, *button_cc_done, *create_character_window, *combobox_rs,
-    *combobox_cs, *textview_cs_desc, *entry_new_character_name, *button_choose_starting_map,
-    *opt_label[NUM_OPT_FIELDS], *opt_combobox[NUM_OPT_FIELDS];
+       *label_cs[NUM_NEW_CHAR_STATS], *label_tot[NUM_NEW_CHAR_STATS],
+       *label_cc_unspent, *textview_rs_desc, *label_cc_desc, *label_cc_status_update,
+       *button_cc_cancel, *create_character_window, *combobox_rs,
+       *combobox_cs, *textview_cs_desc, *entry_new_character_name, *button_choose_starting_map,
+       *opt_label[NUM_OPT_FIELDS], *opt_combobox[NUM_OPT_FIELDS];
 
 static GtkTextMark *text_mark_cs, *text_mark_rs;
 
 /* These are in the choose starting map window */
 static GtkWidget *choose_starting_map_window,
-    *button_csm_done, *button_csm_cancel, *combobox_starting_map;
+       *button_csm_done, *button_csm_cancel, *combobox_starting_map;
 
 GtkTextBuffer *textbuf_starting_map;
 
@@ -138,7 +120,6 @@ static void create_character_set_sensitive(int sensitive)
 {
     int i;
 
-    gtk_widget_set_sensitive(button_cc_done, sensitive);
     gtk_widget_set_sensitive(button_choose_starting_map, sensitive);
     gtk_widget_set_sensitive(entry_new_character_name, sensitive);
     gtk_widget_set_sensitive(combobox_rs, sensitive);
@@ -148,16 +129,18 @@ static void create_character_set_sensitive(int sensitive)
      * no harm in doing so.
      */
 
-    for (i=0; i<NUM_NEW_CHAR_STATS; i++)
+    for (i=0; i<NUM_NEW_CHAR_STATS; i++) {
         gtk_widget_set_sensitive(spinbutton_cc[i], sensitive);
+    }
 
     /* If we do not have any starting maps, no reason to show
      * that button to the player.
      */
-    if (starting_map_number)
+    if (starting_map_number) {
         gtk_widget_show(button_choose_starting_map);
-    else
+    } else {
         gtk_widget_hide(button_choose_starting_map);
+    }
 }
 
 /**
@@ -243,17 +226,20 @@ static void update_all_stats()
         tval = gtk_label_get_text(GTK_LABEL(label_rs[i]));
         statval += atoi(tval);
 
-        /* Might it be good to draw negative stats in red?  Rather
+        /* Might it be good to draw nonpositive stats in red?  Rather
          * than hardcode that, it should be a style
+         * Used to only check for negative stats, but zero is not allowed either.
          */
-        if (statval < 0) negative_stat = 1;
+        if (statval < 1) {
+            negative_stat = 1;
+        }
 
-        sprintf(buf, "%d", statval);
+        snprintf(buf, sizeof(buf), "%d", statval);
         gtk_label_set_text(GTK_LABEL(label_tot[i]), buf);
     }
 
     tmp = stat_points - stat_points_used;
-    sprintf(buf,"%d", tmp);
+    snprintf(buf, sizeof(buf), "%d", tmp);
     gtk_label_set_text(GTK_LABEL(label_cc_unspent), buf);
 
     /* Display some warning messages - we could try and display all the
@@ -261,16 +247,16 @@ static void update_all_stats()
      * perhaps the done button should be inactivated if there are errors.
      */
     if (tmp < 0) {
-        gtk_label_set_text(GTK_LABEL(label_cc_status_update), 
+        gtk_label_set_text(GTK_LABEL(label_cc_status_update),
                            "You have used more than your allotted total attribute points");
     } else if (negative_stat) {
-        gtk_label_set_text(GTK_LABEL(label_cc_status_update), 
-                   "Negative attributes are not allowed - adjust your selections before finishing");
+        gtk_label_set_text(GTK_LABEL(label_cc_status_update),
+                           "Attributes less than 1 are not allowed - adjust your selections before finishing");
 
     } else {
         gtk_label_set_text(GTK_LABEL(label_cc_status_update), "Waiting for player selections");
     }
-    
+
 
 }
 
@@ -280,7 +266,7 @@ static void send_create_player_to_server()
     int i, on_choice, tmp;
     SockList sl;
     char buf[MAX_BUF];
-    uint8 sockbuf[MAX_BUF];
+    guint8 sockbuf[MAX_BUF];
 
     char_name = gtk_entry_get_text(GTK_ENTRY(entry_new_character_name));
 
@@ -364,6 +350,7 @@ static void send_create_player_to_server()
 
     SockList_Send(&sl, csocket.fd);
 
+    keybindings_init(char_name);
 }
 
 
@@ -410,9 +397,6 @@ static int character_data_ok()
 {
     const gchar *char_name;
     int i, stat_points_used=0, tmp[NUM_NEW_CHAR_STATS], negative_stat=0;
-    SockList sl;
-    char buf[MAX_BUF];
-    uint8 sockbuf[MAX_BUF];
 
     char_name = gtk_entry_get_text(GTK_ENTRY(entry_new_character_name));
 
@@ -433,7 +417,7 @@ static int character_data_ok()
     }
 
     if (stat_points_used > stat_points) {
-        gtk_label_set_text(GTK_LABEL(label_cc_status_update), 
+        gtk_label_set_text(GTK_LABEL(label_cc_status_update),
                            "You have used more than your allotted total attribute points");
         show_window(WINDOW_CREATE_CHARACTER);
         return FALSE;
@@ -443,9 +427,9 @@ static int character_data_ok()
      * re-use that value.
      */
     if (negative_stat) {
-        gtk_label_set_text(GTK_LABEL(label_cc_status_update), 
-                   "Negative attributes are not allowed - adjust your selections before finishing");
-        show_window(WINDOW_CREATE_CHARACTER); 
+        gtk_label_set_text(GTK_LABEL(label_cc_status_update),
+                           "Attributes less than 1 are not allowed - adjust your selections before finishing");
+        show_window(WINDOW_CREATE_CHARACTER);
         return FALSE;
     }
 
@@ -460,17 +444,17 @@ static int character_data_ok()
         int result;
 
         dialog =
-            gtk_message_dialog_new(GTK_WINDOW(create_character_window), 
+            gtk_message_dialog_new(GTK_WINDOW(create_character_window),
                                    GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION,
                                    GTK_BUTTONS_YES_NO,
-                                   "%s\n%s\n%s", 
+                                   "%s\n%s\n%s",
                                    "You have not spent all your attribute points.",
                                    "You will be unable to spend these later.",
                                    "Create character anyways?");
         result = gtk_dialog_run(GTK_DIALOG(dialog));
         gtk_widget_destroy(dialog);
         if (result == GTK_RESPONSE_NO) {
-            show_window(WINDOW_CREATE_CHARACTER); 
+            show_window(WINDOW_CREATE_CHARACTER);
             return FALSE;
         }
         /* Otherwise, fall through below */
@@ -484,7 +468,6 @@ static int character_data_ok()
     i = gtk_combo_box_get_active(GTK_COMBO_BOX(combobox_starting_map));
     if (starting_map_number && i == -1) {
         GtkWidget *dialog;
-        int result;
 
         show_window(WINDOW_CHOOSE_MAP);
         dialog =
@@ -492,7 +475,7 @@ static int character_data_ok()
                                    GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_WARNING,
                                    GTK_BUTTONS_OK,
                                    "You must choose a starting map before you can start playing");
-        result = gtk_dialog_run(GTK_DIALOG(dialog));
+        gtk_dialog_run(GTK_DIALOG(dialog));
         gtk_widget_destroy(dialog);
         return FALSE;
     }
@@ -516,10 +499,11 @@ on_button_cc_done(GtkButton *button, gpointer user_data)
         /* If we get here, everything checks out - now we have to
          * send the data to the server.
          */
-        gtk_label_set_text(GTK_LABEL(label_cc_status_update), 
-                       "Sending new character information to server");
+        gtk_label_set_text(GTK_LABEL(label_cc_status_update),
+                           "Sending new character information to server");
         show_window(WINDOW_CREATE_CHARACTER);
         send_create_player_to_server();
+        show_main_client();
     }
 }
 
@@ -528,7 +512,8 @@ on_button_cc_done(GtkButton *button, gpointer user_data)
  * back up the values.
  */
 void
-on_spinbutton_cc (GtkSpinButton *spinbutton, gpointer user_data) {
+on_spinbutton_cc (GtkSpinButton *spinbutton, gpointer user_data)
+{
 
     update_all_stats();
 }
@@ -548,7 +533,7 @@ on_spinbutton_cc (GtkSpinButton *spinbutton, gpointer user_data) {
 void
 on_combobox_rcs_changed(GtkComboBox *box, gpointer user_data)
 {
-    int active_entry, i, opt_start, opt_end;
+    int active_entry, i, opt_start;
     GtkWidget **label_stat;
     Race_Class_Info *rc;
     char buf[256];
@@ -558,8 +543,9 @@ on_combobox_rcs_changed(GtkComboBox *box, gpointer user_data)
     /* I don't think this can ever happen - if we get here,
      * something should be active.
      */
-    if (active_entry == -1)
+    if (active_entry == -1) {
         return;
+    }
 
     /* since we are using a list store, and we are not re-arranging the order,
      * the entry number should match our array number.
@@ -585,7 +571,7 @@ on_combobox_rcs_changed(GtkComboBox *box, gpointer user_data)
         label_stat = label_rs;
         opt_start = RACE_OPT_START;
     } else {
-        LOG(LOG_ERROR, "gtk-v2/src/create_char.c:on_combobox_rcs_changed", 
+        LOG(LOG_ERROR, "gtk-v2/src/create_char.c:on_combobox_rcs_changed",
             "Passed in combobox does not match any combobox");
         return;
     }
@@ -611,7 +597,8 @@ on_combobox_rcs_changed(GtkComboBox *box, gpointer user_data)
         }
         gtk_combo_box_set_active(GTK_COMBO_BOX(opt_combobox[i+opt_start]), 0);
 
-        gtk_label_set(GTK_LABEL(opt_label[i+opt_start]), rc->rc_choice[i].choice_desc);
+        gtk_label_set_text(GTK_LABEL(opt_label[i + opt_start]),
+                           rc->rc_choice[i].choice_desc);
         gtk_widget_show(opt_label[i+opt_start]);
         gtk_widget_show(opt_combobox[i+opt_start]);
         /* No signals are connected - the value of the combo
@@ -624,13 +611,13 @@ on_combobox_rcs_changed(GtkComboBox *box, gpointer user_data)
         gtk_widget_hide(opt_label[i + opt_start]);
         gtk_widget_hide(opt_combobox[i + opt_start]);
     }
-            
+
 
     /* label_stat now points at the array of stats to update, and rc points
      * at either the race or class to get values from.
      */
     for (i=0; i < NUM_NEW_CHAR_STATS; i++) {
-        sprintf(buf, "%+d", rc->stat_adj[stat_mapping[i].rc_offset]);
+        snprintf(buf, sizeof(buf), "%+d", rc->stat_adj[stat_mapping[i].rc_offset]);
         gtk_label_set_text(GTK_LABEL(label_stat[i]), buf);
     }
     update_all_stats();
@@ -654,12 +641,13 @@ void new_char_window_update_info()
     /* We could do the update as we get the data, but it shouldn't take
      * too long to get all the data, and simpler to just do one update
      */
-    if (!stat_points || num_races != used_races || num_classes != used_classes)
+    if (!stat_points || num_races != used_races || num_classes != used_classes) {
         return;
+    }
 
     gtk_label_set_text(GTK_LABEL(label_cc_status_update), "Waiting for player selections");
 
-    sprintf(buf,"%d", stat_points);
+    snprintf(buf, sizeof(buf), "%d", stat_points);
     gtk_label_set_text(GTK_LABEL(label_cc_unspent), buf);
 
     /* Set up the races combobox */
@@ -706,7 +694,7 @@ void new_char_window_update_info()
      */
     for (i=0; i<NUM_NEW_CHAR_STATS; i++) {
         /* Reset any stat values - just makes more sense, but also
-         * possible that starting value set in the glade file may
+         * possible that starting value set in the layout file may
          * be outside of this range.
          */
         gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinbutton_cc[i]), stat_min);
@@ -723,7 +711,7 @@ void new_char_window_update_info()
 
 /**
  * User has hit the 'return to character creation' button - basically
- * meaning that we have to hide the current window and show the 
+ * meaning that we have to hide the current window and show the
  * create_character_window.
  *
  * @param button    ignored
@@ -739,18 +727,16 @@ on_button_csm_cancel(GtkButton *button, gpointer user_data)
 void
 on_combobox_starting_map_changed(GtkComboBox *box, gpointer user_data)
 {
-    int active_entry, i;
-    GtkWidget **label_stat;
-    Race_Class_Info *rc;
-    char buf[256];
+    int active_entry;
 
     active_entry = gtk_combo_box_get_active(box);
 
     /* I don't think this can ever happen - if we get here,
      * something should be active.
      */
-    if (active_entry == -1)
+    if (active_entry == -1) {
         return;
+    }
 
     /* since we are using a list store, and we are not re-arranging the order,
      * the entry number should match our array number.
@@ -766,7 +752,6 @@ on_combobox_starting_map_changed(GtkComboBox *box, gpointer user_data)
  */
 void starting_map_update_info()
 {
-    char buf[256];
     GtkListStore *store;
     GtkTreeIter iter;
     GtkCellRenderer *renderer;
@@ -803,40 +788,38 @@ void starting_map_update_info()
 /**
  * Initializes the create character window.
  */
-void init_create_character_window()
-{
-    GladeXML *xml_tree;
+void init_create_character_window() {
     char tmpbuf[80];
     int i;
     GtkTextIter iter;
     GtkCellRenderer *renderer;
 
-    if (has_init) return;
+    if (has_init) {
+        return;
+    }
     has_init=1;
 
-    create_character_window = glade_xml_get_widget(dialog_xml, "create_character_window");
-    gtk_window_set_transient_for(GTK_WINDOW(create_character_window), GTK_WINDOW(window_root));
+    create_character_window = GTK_WIDGET(gtk_builder_get_object(dialog_xml, "create_character_window"));
+    gtk_window_set_transient_for(GTK_WINDOW(create_character_window), GTK_WINDOW(connect_window));
 
-    xml_tree = glade_get_widget_tree(GTK_WIDGET(create_character_window));
 
-    button_cc_done = glade_xml_get_widget(dialog_xml,"button_cc_done");
-    button_cc_cancel = glade_xml_get_widget(dialog_xml,"button_cc_cancel");
-    button_choose_starting_map = glade_xml_get_widget(dialog_xml,"button_choose_starting_map");
-    label_cc_status_update = glade_xml_get_widget(dialog_xml,"label_cc_status_update");
-    label_cc_desc = glade_xml_get_widget(dialog_xml,"label_cc_desc");
-    label_cc_unspent = glade_xml_get_widget(dialog_xml,"label_cc_unspent");
-    combobox_rs = glade_xml_get_widget(dialog_xml,"combobox_rs");
-    combobox_cs = glade_xml_get_widget(dialog_xml,"combobox_cs");
-    entry_new_character_name = glade_xml_get_widget(dialog_xml,"cc_entry_new_character_name");
+    button_cc_cancel = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"button_cc_cancel"));
+    button_choose_starting_map = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"button_choose_starting_map"));
+    label_cc_status_update = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"label_cc_status_update"));
+    label_cc_desc = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"label_cc_desc"));
+    label_cc_unspent = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"label_cc_unspent"));
+    combobox_rs = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"combobox_rs"));
+    combobox_cs = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"combobox_cs"));
+    entry_new_character_name = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"cc_entry_new_character_name"));
 
-    textview_rs_desc = glade_xml_get_widget(dialog_xml,"textview_rs_desc");
+    textview_rs_desc = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"textview_rs_desc"));
     text_mark_rs = gtk_text_mark_new("rs_start", TRUE);
     gtk_text_buffer_get_start_iter(gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview_rs_desc)),
                                    &iter);
     gtk_text_buffer_add_mark(gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview_rs_desc)),
                              text_mark_rs, &iter);
 
-    textview_cs_desc = glade_xml_get_widget(dialog_xml,"textview_cs_desc");
+    textview_cs_desc = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"textview_cs_desc"));
     text_mark_cs = gtk_text_mark_new("cs_start", TRUE);
     gtk_text_buffer_get_start_iter(gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview_cs_desc)),
                                    &iter);
@@ -845,67 +828,64 @@ void init_create_character_window()
 
     for (i=0; i<NUM_NEW_CHAR_STATS; i++) {
         snprintf(tmpbuf, 80, "spinbutton_cc_%s", stat_mapping[i].widget_suffix);
-        spinbutton_cc[i] = glade_xml_get_widget(dialog_xml, tmpbuf);
+        spinbutton_cc[i] = GTK_WIDGET(gtk_builder_get_object(dialog_xml, tmpbuf));
 
         g_signal_connect ((gpointer) spinbutton_cc[i], "value-changed",
-                          G_CALLBACK (on_spinbutton_cc), (void*)i);
+                          G_CALLBACK (on_spinbutton_cc), NULL);
 
         snprintf(tmpbuf, 80, "label_rs_%s", stat_mapping[i].widget_suffix);
-        label_rs[i] = glade_xml_get_widget(dialog_xml, tmpbuf);
+        label_rs[i] = GTK_WIDGET(gtk_builder_get_object(dialog_xml, tmpbuf));
 
         snprintf(tmpbuf, 80, "label_cs_%s", stat_mapping[i].widget_suffix);
-        label_cs[i] = glade_xml_get_widget(dialog_xml, tmpbuf);
+        label_cs[i] = GTK_WIDGET(gtk_builder_get_object(dialog_xml, tmpbuf));
 
         snprintf(tmpbuf, 80, "label_tot_%s", stat_mapping[i].widget_suffix);
-        label_tot[i] = glade_xml_get_widget(dialog_xml, tmpbuf);
+        label_tot[i] = GTK_WIDGET(gtk_builder_get_object(dialog_xml, tmpbuf));
     }
 
-    /* Note that in the glade file, the numbering starts at 1 */
+    /* Note that in the layout file, the numbering starts at 1 */
     for (i=0; i < NUM_OPT_FIELDS; i++ ) {
         GtkListStore *store;
 
         snprintf(tmpbuf, 80, "opt_label%d", i+1);
-        opt_label[i] = glade_xml_get_widget(dialog_xml, tmpbuf);
+        opt_label[i] = GTK_WIDGET(gtk_builder_get_object(dialog_xml, tmpbuf));
 
         snprintf(tmpbuf, 80, "opt_combobox%d", i+1);
-        opt_combobox[i] = glade_xml_get_widget(dialog_xml, tmpbuf);
+        opt_combobox[i] = GTK_WIDGET(gtk_builder_get_object(dialog_xml, tmpbuf));
 
         gtk_cell_layout_clear(GTK_CELL_LAYOUT(opt_combobox[i]));
         renderer = gtk_cell_renderer_text_new();
         gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(opt_combobox[i]), renderer, FALSE);
         gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(opt_combobox[i]), renderer,
-                                   "text", 0, NULL);
+                                       "text", 0, NULL);
         store = gtk_list_store_new(1, G_TYPE_STRING);
         gtk_combo_box_set_model(GTK_COMBO_BOX(opt_combobox[i]), GTK_TREE_MODEL(store));
 
     }
 
-    g_signal_connect ((gpointer) button_cc_done, "clicked",
-                      G_CALLBACK (on_button_cc_done), NULL);
     g_signal_connect ((gpointer) button_cc_cancel, "clicked",
                       G_CALLBACK (on_button_cc_cancel), NULL);
     g_signal_connect ((gpointer) button_choose_starting_map, "clicked",
                       G_CALLBACK (on_button_choose_starting_map), NULL);
 
     /* For starting map window */
-    choose_starting_map_window =  glade_xml_get_widget(dialog_xml, "choose_starting_map_window");
+    choose_starting_map_window =  GTK_WIDGET(gtk_builder_get_object(dialog_xml, "choose_starting_map_window"));
 
     gtk_window_set_transient_for(GTK_WINDOW(choose_starting_map_window), GTK_WINDOW(window_root));
-    xml_tree = glade_get_widget_tree(GTK_WIDGET(create_character_window));
 
-    create_char_pane[STARTING_MAP_PANE].textview = glade_xml_get_widget(dialog_xml,"textview_starting_map");
+    create_char_pane[STARTING_MAP_PANE].textview = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"textview_starting_map"));
     textbuf_starting_map = gtk_text_view_get_buffer(
-        GTK_TEXT_VIEW(create_char_pane[STARTING_MAP_PANE].textview));
+                               GTK_TEXT_VIEW(create_char_pane[STARTING_MAP_PANE].textview));
     add_tags_to_textbuffer(&create_char_pane[STARTING_MAP_PANE], textbuf_starting_map);
     add_style_to_textbuffer(&create_char_pane[STARTING_MAP_PANE], NULL);
 
     gtk_text_buffer_get_end_iter(create_char_pane[STARTING_MAP_PANE].textbuffer, &iter);
     create_char_pane[STARTING_MAP_PANE].textmark = gtk_text_buffer_create_mark(
-        create_char_pane[STARTING_MAP_PANE].textbuffer, NULL, &iter, FALSE);
+                create_char_pane[STARTING_MAP_PANE].textbuffer, NULL, &iter, FALSE);
 
-    button_csm_done = glade_xml_get_widget(dialog_xml,"button_csm_done");
-    button_csm_cancel = glade_xml_get_widget(dialog_xml,"button_csm_cancel");
-    combobox_starting_map = glade_xml_get_widget(dialog_xml,"combobox_starting_map");
+    button_csm_done = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"button_csm_done"));
+    button_csm_cancel = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"button_csm_cancel"));
+    combobox_starting_map = GTK_WIDGET(gtk_builder_get_object(dialog_xml,"combobox_starting_map"));
 
     g_signal_connect ((gpointer) button_csm_done, "clicked",
                       G_CALLBACK (on_button_cc_done), NULL);
@@ -913,4 +893,3 @@ void init_create_character_window()
                       G_CALLBACK (on_button_csm_cancel), NULL);
 
 }
-
