@@ -39,9 +39,6 @@ extern void config_check();
 extern void config_load(void);
 extern void save_defaults(void);
 extern void config_init(GtkWidget *window_root);
-extern void on_config_button_save_clicked(GtkButton *button, gpointer user_data);
-extern void on_config_button_apply_clicked(GtkButton *button, gpointer user_data);
-extern void on_config_button_close_clicked(GtkButton *button, gpointer user_data);
 extern void on_configure_activate(GtkWidget *menuitem, gpointer user_data);
 extern void save_winpos(void);
 extern void on_save_window_position_activate(GtkMenuItem *menuitem, gpointer user_data);
@@ -130,10 +127,11 @@ extern int main(int argc, char *argv[]);
 extern void get_window_coord(GtkWidget *win, int *x, int *y, int *wx, int *wy, int *w, int *h);
 extern void show_main_client(void);
 /* map.c */
+extern void map_check_resize(void);
 extern void map_init(GtkWidget *window_root);
 extern int display_mapscroll(int dx, int dy);
 extern void resize_map_window(int x, int y);
-extern void draw_map(int redraw);
+extern void draw_map(void);
 extern void display_map_doneupdate(int redraw, int notice);
 /* magicmap.c */
 extern void draw_magic_map(void);
@@ -199,7 +197,6 @@ extern guint8 *rescale_rgba_data(guint8 *data, int *width, int *height, int scal
 extern GdkPixbuf *rgba_to_gdkpixbuf(guint8 *data, int width, int height);
 extern cairo_surface_t *rgba_to_cairo_surface(guint8 *data, int width, int height);
 /* sdl.c */
-extern void init_SDL(GtkWidget *sdl_window, int just_lightmap);
 extern void drawquarterlightmap_sdl(int tl, int tr, int bl, int br, int width, int height, int startx, int starty, int endx, int endy, int destx, int desty);
 extern void sdl_gen_map(int redraw);
 extern int sdl_mapscroll(int dx, int dy);
