@@ -103,6 +103,9 @@ GtkBuilder *dialog_xml, *window_xml;
 GtkWidget *window_root, *magic_map, *connect_window;
 GtkNotebook *main_notebook;
 
+extern time_t last_command_sent;
+extern bool is_afk;
+
 #ifdef WIN32 /* Win32 scripting support */
 static int do_scriptout() {
     script_process(NULL);
@@ -140,6 +143,43 @@ static gboolean redraw(gpointer data) {
     return FALSE;
 }
 
+static void on_auto_afk_response(GtkDialog *self, gint response_id, gpointer user_data) {
+    // It is possible for is_afk to be false because dialog is non-modal.
+    switch (response_id) {
+    case 1:
+        gtk_widget_destroy(GTK_WIDGET(self));
+        break;
+    case 2:
+        if (is_afk) {
+            send_command("afk", 0, true);
+        }
+        want_config[CONFIG_AUTO_AFK] = 0;
+        config_check();
+        save_defaults();
+        gtk_widget_destroy(GTK_WIDGET(self));
+        break;
+    default:
+        // includes closing the pop-up
+        if (is_afk) {
+            send_command("afk", 0, true);
+        }
+        gtk_widget_destroy(GTK_WIDGET(self));
+        break;
+    }
+}
+
+static void auto_afk() {
+    send_command("afk", 0, true);
+    GtkWidget *dialog = gtk_dialog_new_with_buttons("Auto-AFK", GTK_WINDOW(window_root), GTK_DIALOG_DESTROY_WITH_PARENT,
+            "Return to game", 0, "Return to game, but stay AFK", 1, "Return to game, disable auto-AFK", 2, NULL);
+    GtkWidget *label, *content_area;
+    content_area = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
+    label = gtk_label_new("You have been automatically marked as being away.");
+    gtk_container_add(GTK_CONTAINER(content_area), label);
+    g_signal_connect_swapped(dialog, "response", G_CALLBACK(on_auto_afk_response), dialog);
+    gtk_widget_show_all(dialog);
+}
+
 /**
  * Called whenever the server sends a tick command.
  */
@@ -162,15 +202,16 @@ void client_tick(guint32 tick) {
     inventory_tick();
     mapdata_animation();
     g_idle_add(redraw, NULL);
+
+    if (!is_afk && use_config[CONFIG_AUTO_AFK] != 0 && time(NULL) > (last_command_sent + use_config[CONFIG_AUTO_AFK])) {
+        auto_afk();
+    }
 }
 /**
  * Handles client shutdown.
  */
 void on_window_destroy_event(GtkWidget *object, gpointer user_data) {
-#ifdef WIN32
     script_killall();
-#endif
-
     LOG(LOG_DEBUG, "main.c::client_exit", "Exiting with return value 0.");
     exit(0);
 }
@@ -332,7 +373,7 @@ static void init_ui() {
         g_error_free(error);
         exit(EXIT_FAILURE);
     }
-    LOG(LOG_DEBUG, "init_ui", "loaded dialog_xml");
+    LOG(LOG_DEBUG, "init_ui", "loaded dialog_xml '%s'", DIALOG_FILENAME);
 
     /* Load main window using GtkBuilder. */
     window_xml = gtk_builder_new();
@@ -342,7 +383,7 @@ static void init_ui() {
             g_error("Could not load default layout!");
         }
     }
-    LOG(LOG_DEBUG, "init_ui", "loaded window_xml");
+    LOG(LOG_DEBUG, "init_ui", "loaded window_xml '%s'", window_xml_file);
 
     connect_window = GTK_WIDGET(gtk_builder_get_object(dialog_xml, "connect_window"));
     gtk_window_set_transient_for(GTK_WINDOW(connect_window),
@@ -459,11 +500,11 @@ int main(int argc, char *argv[]) {
 
     // Initialize GTK and client library.
     gtk_init(&argc, &argv);
+    parse_args(argc, argv);
     client_init();
 
     // Set defaults, load configuration, and parse arguments.
     config_load();
-    parse_args(argc, argv);
     config_check();
     char *layout = g_path_get_basename(window_xml_file);
     snprintf(VERSION_INFO, MAX_BUF,
