@@ -120,8 +120,7 @@ void map_init(GtkWidget *window_root) {
         // Try to affect pixmap[0] in-place, since it is referenced extensively.
         pixmaps[0]->icon_width = nx;
         pixmaps[0]->icon_height = ny;
-        pixmaps[0]->full_icon_width = nx;
-        pixmaps[0]->full_icon_height = ny;
+        // Do not affect full_icon_width/height, since those are expected to be the unscaled size.
         do_new_image(png_tmp, pixmaps[0]);
     }
 
@@ -135,10 +134,10 @@ void map_init(GtkWidget *window_root) {
  * @param ax Map cell on-screen x-coordinate
  * @param ay Map cell on-screen y-coordinate
  */
-static void draw_pixmap(cairo_t *cr, PixmapInfo *pixmap, int ax, int ay, int off_x, int off_y) {
+static void draw_pixmap(cairo_t *cr, PixmapInfo *pixmap, int ax, int ay) {
     const int dest_x = ax * map_image_size;
     const int dest_y = ay * map_image_size;
-    cairo_set_source_surface(cr, pixmap->map_image, dest_x + global_offset_x + off_x, dest_y + global_offset_y + off_y);
+    cairo_set_source_surface(cr, pixmap->map_image, dest_x, dest_y);
     cairo_paint(cr);
 }
 
@@ -146,8 +145,8 @@ static void draw_smooth_pixmap(cairo_t* cr, PixmapInfo* pixmap,
         const int sx, const int sy, const int dx, const int dy) {
     const int src_x = map_image_size * sx;
     const int src_y = map_image_size * sy;
-    const int dest_x = map_image_size * dx + global_offset_x;
-    const int dest_y = map_image_size * dy + global_offset_y;
+    const int dest_x = map_image_size * dx;
+    const int dest_y = map_image_size * dy;
     cairo_set_source_surface(cr, pixmap->map_image, dest_x - src_x, dest_y - src_y);
     cairo_rectangle(cr, dest_x, dest_y, map_image_size, map_image_size);
     cairo_fill(cr);
@@ -280,7 +279,7 @@ static void drawsmooth(cairo_t *cr, int mx, int my, int layer, int picx, int pic
 /**
  * Draw a single map layer to the given cairo context.
  */
-static void map_draw_layer(cairo_t *cr, int layer, int pass, int mx_start, int nx, int my_start, int ny, int off_x, int off_y) {
+static void map_draw_layer(cairo_t *cr, int layer, int mx_start, int nx, int my_start, int ny) {
     for (int x = 0; x <= nx; x++) {
         for (int y = 0; y <= ny; y++) {
             // Translate on-screen coordinates to virtual map coordinates.
@@ -288,39 +287,100 @@ static void map_draw_layer(cairo_t *cr, int layer, int pass, int mx_start, int n
             const int my = my_start + y;
 
             // Skip current cell if not visible and not using fog of war.
-            if (!use_config[CONFIG_FOGWAR] && mapdata_cell(mx, my)->cleared) {
+            if (!use_config[CONFIG_FOGWAR] && mapdata_cell(mx, my)->state == FOG) {
                 continue;
             }
 
-            if (pass == 0) {
-                int dx, dy, face = mapdata_face_info(mx, my, layer, &dx, &dy);
-                if (face > 0 && pixmaps[face]->map_image != NULL) {
-                    draw_pixmap(cr, pixmaps[face], x + dx, y + dy, off_x, off_y);
-                }
-            } else if (pass == 1) {
-                if (use_config[CONFIG_SMOOTH]) {
-                    drawsmooth(cr, mx, my, layer, x + off_x, y + off_y);
-                }
+            // Draw pixmaps
+            int dx, dy, face = mapdata_face_info(mx, my, layer, &dx, &dy);
+            if (face > 0 && pixmaps[face]->map_image != NULL) {
+                draw_pixmap(cr, pixmaps[face], x + dx, y + dy);
+            }
+
+            // Draw smoothing
+            if (use_config[CONFIG_SMOOTH]) {
+                drawsmooth(cr, mx, my, layer, x, y);
             }
         }
     }
 }
 
-/**
- * Draw darkness layer to a location on screen.
- */
-static void mapcell_draw_darkness(cairo_t *cr, int ax, int ay, int mx, int my) {
-    cairo_rectangle(cr, ax * map_image_size + global_offset_x, ay * map_image_size + global_offset_y,
-            map_image_size, map_image_size);
-
+static double mapcell_darkness(int mx, int my) {
     double opacity = mapdata_cell(mx, my)->darkness / 192.0 * 0.6;
-
-    if (use_config[CONFIG_FOGWAR] && mapdata_cell(mx, my)->cleared) {
+    if (use_config[CONFIG_FOGWAR] && mapdata_cell(mx, my)->state == FOG) {
         opacity += 0.2;
     }
+    return opacity;
+}
 
-    cairo_set_source_rgba(cr, 0, 0, 0, opacity);
-    cairo_fill(cr);
+static void draw_darkness(cairo_t *cr, int nx, int ny, int mx_start, int my_start) {
+    /**
+     * Create light map nx wide, ny tall. Add a border 1px around to get rid
+     * of edge effects.
+     */
+    cairo_surface_t *cst_lm = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, nx+2, ny+2);
+    cairo_t *cr_lm = cairo_create(cst_lm);
+    for (int x = -1; x <= nx+1; x++) {
+        for (int y = -1; y <= ny+1; y++) {
+            const int dx = MIN(MAX(0, x), nx);
+            const int dy = MIN(MAX(0, y), ny);
+
+            // Map coordinate to get darkness information from
+            const int mx = mx_start + dx;
+            const int my = my_start + dy;
+
+            // Destination coordinates on light map
+            const int ax = x + 1;
+            const int ay = y + 1;
+
+            cairo_rectangle(cr_lm, ax, ay, 1, 1);
+            cairo_set_source_rgba(cr_lm, 0, 0, 0, mapcell_darkness(mx, my));
+            cairo_fill(cr_lm);
+        }
+    }
+    cairo_destroy(cr_lm);
+
+    // Scale up light map and draw to map.
+    cairo_scale(cr, map_image_size, map_image_size);
+    cairo_translate(cr, -1, -1);
+    cairo_set_source_surface(cr, cst_lm, 0, 0);
+    switch (use_config[CONFIG_LIGHTING]) {
+        case CFG_LT_TILE:
+            cairo_pattern_set_filter(cairo_get_source(cr), CAIRO_FILTER_NEAREST);
+            break;
+        case CFG_LT_PIXEL:
+            cairo_pattern_set_filter(cairo_get_source(cr), CAIRO_FILTER_GOOD);
+            break;
+        case CFG_LT_PIXEL_BEST:
+            cairo_pattern_set_filter(cairo_get_source(cr), CAIRO_FILTER_BEST);
+            break;
+    }
+    cairo_paint(cr);
+    cairo_surface_destroy(cst_lm);
+}
+
+// Draw move-to tile.
+static void draw_move_to(cairo_t *cr, int mx_start, int my_start) {
+    int mx = move_to_x;
+    int my = move_to_y;
+    int x = mx - mx_start;
+    int y = my - my_start;
+    if (!is_at_moveto()) {
+        int sx = x * map_image_size;
+        int sy = y * map_image_size;
+        cairo_rectangle(cr, sx, sy, map_image_size, map_image_size);
+        if (move_to_attack) {
+            cairo_set_source_rgb(cr, 1, 0, 0); // red to attack
+        } else {
+            cairo_set_source_rgb(cr, 1, 1, 0); // yellow to walk
+        }
+        cairo_set_line_width(cr, 2);
+        cairo_stroke(cr);
+        cairo_rectangle(cr, sx + 2, sy + 2, map_image_size - 4, map_image_size - 4);
+        cairo_set_source_rgb(cr, 0, 0, 0); // black
+        cairo_set_line_width(cr, 1);
+        cairo_stroke(cr);
+    }
 }
 
 /**
@@ -362,41 +422,20 @@ static void gtk_map_redraw() {
     cairo_rectangle(cr, 0, 0, ew, eh);
     cairo_fill(cr);
 
+    // Set global offset (after blanking background)
+    cairo_translate(cr, global_offset_x, global_offset_y);
+
+    // Draw layer-by-layer. Drawing cell-by-cell, looping over the layers,
+    // doesn't work because big faces need to be correctly layered on top.
     for (int layer = 0; layer < MAXLAYERS; layer++) {
-        map_draw_layer(cr, layer, 0, mx_start, nx, my_start, ny, 0, 0);
-        map_draw_layer(cr, layer, 1, mx_start, nx, my_start, ny, 0, 0);
+        map_draw_layer(cr, layer, mx_start, nx, my_start, ny);
     }
 
-    for (int x = 0; x <= nx; x++) {
-        for (int y = 0; y <= ny; y++) {
-            // Translate on-screen coordinates to virtual map coordinates.
-            const int mx = mx_start + x;
-            const int my = my_start + y;
+    draw_move_to(cr, mx_start, my_start);
 
-            mapcell_draw_darkness(cr, x, y, mx, my);
-            mapdata_cell(mx, my)->need_update = 0;
-            mapdata_cell(mx, my)->need_resmooth = 0;
-
-            // Draw move-to tile.
-            if (mx == move_to_x && my == move_to_y && !is_at_moveto()) {
-                int sx = x * map_image_size;
-                int sy = y * map_image_size;
-                cairo_rectangle(cr, sx + global_offset_x, sy + global_offset_y, map_image_size, map_image_size);
-                if (move_to_attack) {
-                    cairo_set_source_rgb(cr, 1, 0, 0); // red to attack
-                } else {
-                    cairo_set_source_rgb(cr, 1, 1, 0); // yellow to walk
-                }
-                cairo_set_line_width(cr, 2);
-                cairo_stroke(cr);
-                cairo_rectangle(cr, sx + global_offset_x + 2, sy + global_offset_y + 2, map_image_size - 4, map_image_size - 4);
-                cairo_set_source_rgb(cr, 0, 0, 0); // black
-                cairo_set_line_width(cr, 1);
-                cairo_stroke(cr);
-            }
-        }
+    if (use_config[CONFIG_LIGHTING] != 0) {
+        draw_darkness(cr, nx, ny, mx_start, my_start);
     }
-
     cairo_destroy(cr);
 
     // Copy the double buffer on the map drawing area.
@@ -405,7 +444,7 @@ static void gtk_map_redraw() {
         cairo_scale(map_cr, scale, scale);
     }
     cairo_set_source_surface(map_cr, cst, 0, 0);
-    if (use_config[CONFIG_MAPSCALE] > 100) {
+    if (use_config[CONFIG_MAPSCALE] % 100 == 0) {
         cairo_pattern_set_filter(cairo_get_source(cr), CAIRO_FILTER_NEAREST);
     }
     cairo_paint(map_cr);
@@ -429,12 +468,6 @@ static void update_global_offset() {
     dy = ((want_offset_y*map_image_size) - global_offset_y)*predict_alpha/100.0;
     global_offset_x += dx;
     global_offset_y += dy;
-
-    // Snap global offset to zero when we're at the right square.
-    if (want_offset_x == 0 && want_offset_y == 0) {
-        global_offset_x = 0;
-        global_offset_y = 0;
-    }
 }
 
 /**
@@ -454,10 +487,11 @@ void draw_map() {
     }
 
     const unsigned int target_redraw = 100000;
-    if (elapsed > target_redraw) {
+    const int no_resize_above = 100; // don't resize above this value of mapscale
+    if (elapsed > target_redraw && use_config[CONFIG_MAPSCALE] < no_resize_above) {
+        use_config[CONFIG_MAPSCALE] = MIN(use_config[CONFIG_MAPSCALE] + 5, no_resize_above);
         LOG(LOG_DEBUG, "draw_map", "Increasing mapscale to %d to reduce draw time below %u us",
                 use_config[CONFIG_MAPSCALE], target_redraw);
-        use_config[CONFIG_MAPSCALE] += 5;
         map_check_resize();
     }
 }
