@@ -1,50 +1,34 @@
-const char * const rcsid_gtk2_pickup_c =
-    "$Id: pickup.c 13958 2010-10-02 09:34:23Z ryo_saeba $";
-
 /*
-    Crossfire client, a client program for the crossfire program.
-
-    Copyright (C) 2005-2010 Mark Wedel & Crossfire Development Team
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-    The author can be reached via e-mail to crossfire@metalforge.org
-*/
+ * Crossfire -- cooperative multi-player graphical RPG and adventure game
+ *
+ * Copyright (c) 1999-2013 Mark Wedel and the Crossfire Development Team
+ * Copyright (c) 1992 Frank Tore Johansen
+ *
+ * Crossfire is free software and comes with ABSOLUTELY NO WARRANTY. You are
+ * welcome to redistribute it under certain conditions. For details, see the
+ * 'LICENSE' and 'COPYING' files.
+ *
+ * The authors can be reached via e-mail to crossfire-devel@real-time.com
+ */
 
 /**
- * @file gtk-v2/src/pickup.c
+ * @file
  * This file covers the pickup menu items.  We only implement the new pickup
  * code - it seems to me that it should be able to cover everything the old
  * pickup mode does.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
+#include "client.h"
 
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 
-#include "client.h"
 #include "main.h"
 #include "image.h"
 #include "gtk2proto.h"
 
 typedef struct {
     GtkWidget   *menuitem;
-    uint32      pickup_mode;
+    guint32      pickup_mode;
 } PickupMapping;
 
 #define MAX_PICKUPS 50
@@ -101,7 +85,7 @@ static unsigned int pmode=0, no_recurse=0;
 
 /**
  * Handles the pickup operations.  Unfortunately, it isn't easy (possible?)
- * in glade to attach values to the menu items.
+ * in layout to attach values to the menu items.
  *
  * @param on is TRUE if the button is activated, 0 if it is off.
  * @param val is the PU_ bitmasks to set/clear.
@@ -110,15 +94,18 @@ static void new_menu_pickup(int on, int val)
 {
     char modestr[128];
 
-    if (no_recurse) return;
+    if (no_recurse) {
+        return;
+    }
 
-    if (on)
+    if (on) {
         pmode |= val | PU_NEWMODE;
-    else
+    } else {
         pmode &= ~val;
+    }
 
     draw_ext_info(NDI_BLACK, MSG_TYPE_CLIENT, MSG_TYPE_CLIENT_NOTICE,
-        "To set this pickup mode to a key, use:");
+                  "To set this pickup mode to a key, use:");
 
     snprintf(modestr, sizeof(modestr), "bind pickup %u",pmode);
     draw_ext_info(NDI_BLACK, MSG_TYPE_CLIENT, MSG_TYPE_CLIENT_NOTICE, modestr);
@@ -245,7 +232,7 @@ on_menu_magical_items_activate         (GtkMenuItem     *menuitem,
 
 void
 on_menu_potions_activate                (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), PU_POTION);
 }
@@ -273,21 +260,21 @@ on_menu_not_cursed_activate            (GtkMenuItem     *menuitem,
 
 void
 on_menu_jewels_activate                  (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), PU_JEWELS);
 }
 
 void
 on_menu_containers_activate                  (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), PU_CONTAINERS);
 }
 
 void
 on_menu_flesh_activate                  (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), PU_FLESH);
 }
@@ -330,7 +317,7 @@ on_menu_arrows_activate                (GtkMenuItem     *menuitem,
 
 void
 on_menu_ratio_pickup_off_activate       (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), 0);
 }
@@ -344,63 +331,63 @@ on_menu_ratio_5_activate               (GtkMenuItem     *menuitem,
 
 void
 on_menu_ratio_10_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), 2);
 }
 
 void
 on_menu_ratio_15_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), 3);
 }
 
 void
 on_menu_ratio_20_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), 4);
 }
 
 void
 on_menu_ratio_25_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), 5);
 }
 
 void
 on_menu_ratio_30_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), 6);
 }
 
 void
 on_menu_ratio_35_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), 7);
 }
 
 void
 on_menu_ratio_40_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), 8);
 }
 
 void
 on_menu_ratio_45_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), 9);
 }
 
 void
 on_menu_ratio_50_activate               (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+        gpointer         user_data)
 {
     new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), 10);
 }
@@ -414,13 +401,14 @@ on_menu_ratio_50_activate               (GtkMenuItem     *menuitem,
 void pickup_init(GtkWidget *window_root)
 {
     static int has_init=0;
-    GladeXML *xml_tree;
 
     /*
      * There isn't really any harm doing this multiple times, but isn't any
      * point either.
      */
-    if (has_init) return;
+    if (has_init) {
+        return;
+    }
     has_init=1;
 
     /*
@@ -437,189 +425,188 @@ void pickup_init(GtkWidget *window_root)
      * change it.
      */
 
-    xml_tree = glade_get_widget_tree(GTK_WIDGET(window_root));
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "do_not_pickup");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "do_not_pickup"));
     pickup_mapping[num_pickups].pickup_mode = PU_INHIBIT;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "stop_before_pickup");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "stop_before_pickup"));
     pickup_mapping[num_pickups].pickup_mode = PU_STOP;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "body_armor");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "body_armor"));
     pickup_mapping[num_pickups].pickup_mode = PU_ARMOUR;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "boots");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "boots"));
     pickup_mapping[num_pickups].pickup_mode = PU_BOOTS;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "cloaks");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "cloaks"));
     pickup_mapping[num_pickups].pickup_mode = PU_CLOAK;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "gloves");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "gloves"));
     pickup_mapping[num_pickups].pickup_mode = PU_GLOVES;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "helmets");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "helmets"));
     pickup_mapping[num_pickups].pickup_mode = PU_HELMET;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "shields");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "shields"));
     pickup_mapping[num_pickups].pickup_mode = PU_SHIELD;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "skillscrolls");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "skillscrolls"));
     pickup_mapping[num_pickups].pickup_mode = PU_SKILLSCROLL;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "normal_book_scrolls");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "normal_book_scrolls"));
     pickup_mapping[num_pickups].pickup_mode = PU_READABLES;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "spellbooks");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "spellbooks"));
     pickup_mapping[num_pickups].pickup_mode = PU_SPELLBOOK;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "drinks");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "drinks"));
     pickup_mapping[num_pickups].pickup_mode = PU_DRINK;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "food");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "food"));
     pickup_mapping[num_pickups].pickup_mode = PU_FOOD;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "flesh");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "flesh"));
     pickup_mapping[num_pickups].pickup_mode = PU_FLESH;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "keys");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "keys"));
     pickup_mapping[num_pickups].pickup_mode = PU_KEY;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "magical_items");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "magical_items"));
     pickup_mapping[num_pickups].pickup_mode = PU_MAGICAL;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "potions");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "potions"));
     pickup_mapping[num_pickups].pickup_mode = PU_POTION;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "valuables");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "valuables"));
     pickup_mapping[num_pickups].pickup_mode = PU_VALUABLES;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "wands_rods_horns");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "wands_rods_horns"));
     pickup_mapping[num_pickups].pickup_mode = PU_MAGIC_DEVICE;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "jewels");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "jewels"));
     pickup_mapping[num_pickups].pickup_mode = PU_JEWELS;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "containers");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "containers"));
     pickup_mapping[num_pickups].pickup_mode = PU_CONTAINERS;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "all_weapons");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "all_weapons"));
     pickup_mapping[num_pickups].pickup_mode = PU_ALLWEAPON;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "missile_weapons");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "missile_weapons"));
     pickup_mapping[num_pickups].pickup_mode = PU_MISSILEWEAPON;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "bows");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "bows"));
     pickup_mapping[num_pickups].pickup_mode = PU_BOW;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "arrows");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "arrows"));
     pickup_mapping[num_pickups].pickup_mode = PU_ARROW;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "ratio_pickup_off");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "ratio_pickup_off"));
     pickup_mapping[num_pickups].pickup_mode = ~PU_RATIO;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "ratio_5");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "ratio_5"));
     pickup_mapping[num_pickups].pickup_mode = 1;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "ratio_10");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "ratio_10"));
     pickup_mapping[num_pickups].pickup_mode = 2;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "ratio_15");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "ratio_15"));
     pickup_mapping[num_pickups].pickup_mode = 3;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "ratio_20");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "ratio_20"));
     pickup_mapping[num_pickups].pickup_mode = 4;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "ratio_25");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "ratio_25"));
     pickup_mapping[num_pickups].pickup_mode = 5;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "ratio_30");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "ratio_30"));
     pickup_mapping[num_pickups].pickup_mode = 6;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "ratio_35");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "ratio_35"));
     pickup_mapping[num_pickups].pickup_mode = 7;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "ratio_40");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "ratio_40"));
     pickup_mapping[num_pickups].pickup_mode = 8;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "ratio_45");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "ratio_45"));
     pickup_mapping[num_pickups].pickup_mode = 9;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "ratio_50");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "ratio_50"));
     pickup_mapping[num_pickups].pickup_mode = 10;
     num_pickups++;
 
     pickup_mapping[num_pickups].menuitem =
-        glade_xml_get_widget(xml_tree, "not_cursed");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "not_cursed"));
     pickup_mapping[num_pickups].pickup_mode = PU_NOT_CURSED;
     num_pickups++;
 
@@ -640,7 +627,7 @@ void pickup_init(GtkWidget *window_root)
 /**
  * We get pickup information from server, update our status.
  */
-void client_pickup(uint32 pickup)
+void client_pickup(guint32 pickup)
 {
     int i;
 
@@ -656,7 +643,7 @@ void client_pickup(uint32 pickup)
 
     for (i=0; i < num_pickups; i++) {
         if ((pickup & ~PU_RATIO) & pickup_mapping[i].pickup_mode ||
-            (pickup & PU_RATIO) == pickup_mapping[i].pickup_mode) {
+                (pickup & PU_RATIO) == pickup_mapping[i].pickup_mode) {
             gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(pickup_mapping[i].menuitem), 1);
         } else {
             gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(pickup_mapping[i].menuitem), 0);
