@@ -1,55 +1,40 @@
-const char * const rcsid_gtk2_spells_c =
-    "$Id: spells.c 13816 2010-09-15 05:01:57Z kbulgrien $";
 /*
-    Crossfire client, a client program for the crossfire program.
-
-    Copyright (C) 2006-2007,2010 Mark Wedel & Crossfire Development Team
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-    The author can be reached via e-mail to crossfire@metalforge.org
-*/
+ * Crossfire -- cooperative multi-player graphical RPG and adventure game
+ *
+ * Copyright (c) 1999-2013 Mark Wedel and the Crossfire Development Team
+ * Copyright (c) 1992 Frank Tore Johansen
+ *
+ * Crossfire is free software and comes with ABSOLUTELY NO WARRANTY. You are
+ * welcome to redistribute it under certain conditions. For details, see the
+ * 'LICENSE' and 'COPYING' files.
+ *
+ * The authors can be reached via e-mail to crossfire-devel@real-time.com
+ */
 
 /**
- * @file gtk-v2/src/spells.c
+ * @file
  * Handles spell related functionality.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
-#include <gtk/gtk.h>
-#include <glade/glade.h>
-
 #include "client.h"
 
+#include <assert.h>
+#include <gtk/gtk.h>
+
 #include "image.h"
 #include "metaserver.h"
 #include "main.h"
 #include "gtk2proto.h"
 
 enum Styles {
-   Style_Attuned, Style_Repelled, Style_Denied, Style_Normal, Style_Last
+    Style_Attuned, Style_Repelled, Style_Denied, Style_Normal, Style_Last
 };
 
 static GtkListStore     *spell_store;
 static GtkTreeSelection *spell_selection;
 static GtkWidget        *spell_window, *spell_invoke,
-                        *spell_cast, *spell_options, *spell_treeview,
-                        *spell_label[Style_Last], *spell_eventbox[Style_Last];
+       *spell_cast, *spell_options, *spell_treeview,
+       *spell_label[Style_Last], *spell_eventbox[Style_Last];
 
 enum {
     LIST_IMAGE,  LIST_NAME,  LIST_LEVEL,      LIST_TIME,        LIST_COST,
@@ -85,14 +70,15 @@ void spell_get_styles(void)
     static int style_has_init=0;
 
     for (i=0; i < Style_Last; i++) {
-        if (style_has_init && spell_styles[i]) g_object_unref(spell_styles[i]);
+        if (style_has_init && spell_styles[i]) {
+            g_object_unref(spell_styles[i]);
+        }
         tmp_style =
             gtk_rc_get_style_by_paths(
                 gtk_settings_get_default(), NULL, Style_Names[i], G_TYPE_NONE);
         if (tmp_style) {
             spell_styles[i] = g_object_ref(tmp_style);
-        }
-        else {
+        } else {
             LOG(LOG_INFO, "spells.c::spell_get_styles",
                 "Unable to find style for %s", Style_Names[i]);
             spell_styles[i] = NULL;
@@ -135,7 +121,8 @@ static gboolean spell_selection_func(GtkTreeSelection *selection,
  * @param widget
  * @param user_data
  */
-void on_spell_window_size_allocate(GtkWidget *widget, gpointer user_data) {
+void on_spell_window_size_allocate(GtkWidget *widget, gpointer user_data)
+{
     guint i;
     guint width;
     gboolean valid;
@@ -143,9 +130,11 @@ void on_spell_window_size_allocate(GtkWidget *widget, gpointer user_data) {
     guint column_count;
     GList *column_list;
     GtkTreeViewColumn *column;
- 
+
     /* If the spell window has not been set up yet, do nothing. */
-    if (!has_init) return;
+    if (!has_init) {
+        return;
+    }
     /*
      * How wide is the spell window?
      */
@@ -210,7 +199,9 @@ void update_spell_information(void)
     PangoFontDescription *font=NULL;
 
     /* If the window/spellstore hasn't been created, return. */
-    if (!has_init) return;
+    if (!has_init) {
+        return;
+    }
 
     cpl.spells_updated = 0;
 
@@ -222,10 +213,10 @@ void update_spell_information(void)
     for (i=0; i < Style_Last; i++) {
         if (spell_styles[i]) {
             gtk_widget_modify_fg(spell_label[i],
-                GTK_STATE_NORMAL, &spell_styles[i]->text[GTK_STATE_NORMAL]);
+                                 GTK_STATE_NORMAL, &spell_styles[i]->text[GTK_STATE_NORMAL]);
             gtk_widget_modify_font(spell_label[i], spell_styles[i]->font_desc);
             gtk_widget_modify_bg(spell_eventbox[i],
-                GTK_STATE_NORMAL, &spell_styles[i]->base[GTK_STATE_NORMAL]);
+                                 GTK_STATE_NORMAL, &spell_styles[i]->base[GTK_STATE_NORMAL]);
         } else {
             gtk_widget_modify_fg(spell_label[i],GTK_STATE_NORMAL, NULL);
             gtk_widget_modify_font(spell_label[i], NULL);
@@ -238,11 +229,12 @@ void update_spell_information(void)
         gtk_list_store_append(spell_store, &iter);
 
         buf[0] = 0;
-        if (spell->sp)
+        if (spell->sp) {
             snprintf(buf, sizeof(buf), "%d Mana ", spell->sp);
+        }
         if (spell->grace)
             snprintf(buf + strlen(buf), sizeof(buf) - strlen(buf),
-                         "%d Grace", spell->grace);
+                     "%d Grace", spell->grace);
 
         if (spell->path & cpl.stats.denied) {
             row_style = spell_styles[Style_Denied];
@@ -250,7 +242,9 @@ void update_spell_information(void)
             row_style = spell_styles[Style_Repelled];
         } else if (spell->path & cpl.stats.attuned) {
             row_style = spell_styles[Style_Attuned];
-        } else row_style = spell_styles[Style_Normal];
+        } else {
+            row_style = spell_styles[Style_Normal];
+        }
 
         if (row_style) {
             foreground = &row_style->text[GTK_STATE_NORMAL];
@@ -264,6 +258,7 @@ void update_spell_information(void)
 
         gtk_list_store_set(
             spell_store, &iter,
+            LIST_IMAGE, (GdkPixbuf*) pixmaps[spell->face]->full_icon_image,
             LIST_NAME, spell->name,
             LIST_LEVEL, spell->level,
             LIST_COST, buf,
@@ -285,37 +280,34 @@ void update_spell_information(void)
  * @param menuitem
  * @param user_data
  */
-void on_spells_activate(GtkMenuItem *menuitem, gpointer user_data)
-{
-    GladeXML *xml_tree;
+void on_spells_activate(GtkMenuItem *menuitem, gpointer user_data) {
     GtkWidget *widget;
 
     if (!has_init) {
         GtkCellRenderer *renderer;
         GtkTreeViewColumn *column;
 
-        spell_window = glade_xml_get_widget(dialog_xml, "spell_window");
-        xml_tree = glade_get_widget_tree(GTK_WIDGET(spell_window));
+        spell_window = GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_window"));
 
-        spell_invoke = glade_xml_get_widget(xml_tree,"spell_invoke");
-        spell_cast = glade_xml_get_widget(xml_tree,"spell_cast");
-        spell_options = glade_xml_get_widget(xml_tree,"spell_options");
-        spell_treeview = glade_xml_get_widget(xml_tree, "spell_treeview");
+        spell_invoke = GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_invoke"));
+        spell_cast = GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_cast"));
+        spell_options = GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_options"));
+        spell_treeview = GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_treeview"));
 
         g_signal_connect((gpointer) spell_window, "size-allocate",
-            G_CALLBACK(on_spell_window_size_allocate), NULL);
+                         G_CALLBACK(on_spell_window_size_allocate), NULL);
         g_signal_connect((gpointer) spell_window, "delete-event",
-            G_CALLBACK(gtk_widget_hide_on_delete), NULL);
+                         G_CALLBACK(gtk_widget_hide_on_delete), NULL);
         g_signal_connect((gpointer) spell_treeview, "row_activated",
-            G_CALLBACK(on_spell_treeview_row_activated), NULL);
+                         G_CALLBACK(on_spell_treeview_row_activated), NULL);
         g_signal_connect((gpointer) spell_cast, "clicked",
-            G_CALLBACK(on_spell_cast_clicked), NULL);
+                         G_CALLBACK(on_spell_cast_clicked), NULL);
         g_signal_connect((gpointer) spell_invoke, "clicked",
-            G_CALLBACK(on_spell_invoke_clicked), NULL);
+                         G_CALLBACK(on_spell_invoke_clicked), NULL);
 
-        widget = glade_xml_get_widget(xml_tree, "spell_close");
+        widget = GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_close"));
         g_signal_connect((gpointer) widget, "clicked",
-            G_CALLBACK(on_spell_close_clicked), NULL);
+                         G_CALLBACK(on_spell_close_clicked), NULL);
 
         spell_store =
             gtk_list_store_new(
@@ -348,6 +340,15 @@ void on_spells_activate(GtkMenuItem *menuitem, gpointer user_data)
          * Note: Cell alignment is set to top right instead of the default,
          * to improve readability when descriptions wrap to multiple lines.
          */
+
+        renderer = gtk_cell_renderer_pixbuf_new();
+        renderer->xalign = 0;
+        renderer->yalign = 0;
+        column = gtk_tree_view_column_new_with_attributes(
+                     "?", renderer, "pixbuf", LIST_IMAGE, NULL);
+        gtk_tree_view_append_column(GTK_TREE_VIEW(spell_treeview), column);
+        gtk_tree_view_column_set_sort_column_id(column, LIST_IMAGE);
+        
         renderer = gtk_cell_renderer_text_new();
         renderer->xalign = 0;
         renderer->yalign = 0;
@@ -440,7 +441,7 @@ void on_spells_activate(GtkMenuItem *menuitem, gpointer user_data)
          * column size that is appropriate for the dialog's default width.
          */
         g_object_set(G_OBJECT(renderer),
-            "wrap-width", 300, "wrap-mode", PANGO_WRAP_WORD, NULL);
+                     "wrap-width", 300, "wrap-mode", PANGO_WRAP_WORD, NULL);
         /*
          * Preserve the description text cell renderer pointer to facilitate
          * setting the wrap-width relative to the dialog's size and content.
@@ -458,13 +459,13 @@ void on_spells_activate(GtkMenuItem *menuitem, gpointer user_data)
 
         /* The style code will set the colors for these */
         spell_label[Style_Attuned] =
-            glade_xml_get_widget(xml_tree, "spell_label_attuned");
+            GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_label_attuned"));
         spell_label[Style_Repelled] =
-            glade_xml_get_widget(xml_tree, "spell_label_repelled");
+            GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_label_repelled"));
         spell_label[Style_Denied] =
-            glade_xml_get_widget(xml_tree, "spell_label_denied");
+            GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_label_denied"));
         spell_label[Style_Normal] =
-            glade_xml_get_widget(xml_tree, "spell_label_normal");
+            GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_label_normal"));
 
         /* We use eventboxes because the label widget is a transparent widget.
          * We can't set the background in it and have it work.  But we can set
@@ -472,13 +473,13 @@ void on_spells_activate(GtkMenuItem *menuitem, gpointer user_data)
          * eventbox.
          */
         spell_eventbox[Style_Attuned] =
-            glade_xml_get_widget(xml_tree, "spell_eventbox_attuned");
+            GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_eventbox_attuned"));
         spell_eventbox[Style_Repelled] =
-            glade_xml_get_widget(xml_tree, "spell_eventbox_repelled");
+            GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_eventbox_repelled"));
         spell_eventbox[Style_Denied] =
-            glade_xml_get_widget(xml_tree, "spell_eventbox_denied");
+            GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_eventbox_denied"));
         spell_eventbox[Style_Normal] =
-            glade_xml_get_widget(xml_tree, "spell_eventbox_normal");
+            GTK_WIDGET(gtk_builder_get_object(dialog_xml, "spell_eventbox_normal"));
     }
     gtk_widget_set_sensitive(spell_invoke, FALSE);
     gtk_widget_set_sensitive(spell_cast, FALSE);
@@ -503,24 +504,7 @@ void on_spell_treeview_row_activated(GtkTreeView       *treeview,
                                      GtkTreeViewColumn *column,
                                      gpointer           user_data)
 {
-    int tag;
-    char command[MAX_BUF];
-    const char *options=NULL;
-    GtkTreeIter iter;
-    GtkTreeModel *model;
-
-    model = gtk_tree_view_get_model(treeview);
-    if (gtk_tree_model_get_iter(model, &iter, path)) {
-        gtk_tree_model_get(model, &iter, LIST_TAG, &tag, -1);
-
-        if (!tag) {
-            LOG(LOG_ERROR, "spells.c::on_spell_cast_clicked",
-                "Unable to get spell tag\n");
-            return;
-        }
-        snprintf(command, MAX_BUF-1, "cast %d %s", tag, options);
-        send_command(command, -1, 1);
-    }
+    on_spell_cast_clicked(NULL, NULL);
 }
 
 /**
@@ -571,7 +555,7 @@ void on_spell_invoke_clicked(GtkButton *button, gpointer user_data)
 
         if (!tag) {
             LOG(LOG_ERROR, "spells.c::on_spell_invoke_clicked",
-                    "Unable to get spell tag\n");
+                "Unable to get spell tag\n");
             return;
         }
         snprintf(command, MAX_BUF-1, "invoke %d %s", tag, options);
