@@ -1,41 +1,26 @@
-const char * const rcsid_gtk2_stats_c =
-    "$Id: stats.c 14240 2011-01-12 06:31:21Z mwedel $";
 /*
-    Crossfire client, a client program for the crossfire program.
-
-    Copyright (C) 2005-2007 Mark Wedel & Crossfire Development Team
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-    The author can be reached via e-mail to crossfire@metalforge.org
-*/
+ * Crossfire -- cooperative multi-player graphical RPG and adventure game
+ *
+ * Copyright (c) 1999-2013 Mark Wedel and the Crossfire Development Team
+ * Copyright (c) 1992 Frank Tore Johansen
+ *
+ * Crossfire is free software and comes with ABSOLUTELY NO WARRANTY. You are
+ * welcome to redistribute it under certain conditions. For details, please
+ * see COPYING and LICENSE.
+ *
+ * The authors can be reached via e-mail at <crossfire@metalforge.org>.
+ */
 
 /**
- * @file gtk-v2/src/stats.c
+ * @file
  * Support for character statistics.
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
+#include "client.h"
 
 #include <assert.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 
-#include "client.h"
 #include "main.h"
 #include "image.h"
 #include "gtk2proto.h"
@@ -51,8 +36,6 @@ static const char * const stat_bar_names[MAX_STAT_BARS] = {
     "hp", "sp", "grace", "food", "exp"
 };
 
-static GtkWidget *stat_current[MAX_STAT_BARS];
-static GtkWidget *stat_max[MAX_STAT_BARS];
 static GtkWidget *stat_bar[MAX_STAT_BARS];
 
 #define STYLE_NORMAL        0
@@ -115,7 +98,7 @@ typedef struct {
 
 static StatWindow statwindow;
 
-int need_mapping_update=1;
+static gboolean need_mapping_update;
 
 static int lastval[MAX_STAT_BARS], lastmax[MAX_STAT_BARS];
 
@@ -147,8 +130,9 @@ void stats_get_styles(void)
                 }
                 LOG(LOG_INFO, "stats.c::stats_get_styles()", "Unable to find style '%s'", buf);
             } else {
-                if (!bar_colors[stat_bar][sub_style])
+                if (!bar_colors[stat_bar][sub_style]) {
                     bar_colors[stat_bar][sub_style] = calloc(1, sizeof(GdkColor));
+                }
                 memcpy(bar_colors[stat_bar][sub_style],
                        &tmp_style->base[GTK_STATE_SELECTED], sizeof(GdkColor));
             }
@@ -160,60 +144,52 @@ void stats_get_styles(void)
  * Associate the XML-defined widgets with pointers by name reference.
  * @param *window_root
  */
-void stats_init(GtkWidget *window_root)
-{
+void stats_init(GtkWidget *window_root) {
     int i, x, y;
     char buf[MAX_BUF];
-    GladeXML *xml_tree;
 
-    xml_tree = glade_get_widget_tree(GTK_WIDGET(window_root));
     for (i=0; i<MAX_STAT_BARS; i++) {
-        snprintf(buf, sizeof(buf), "label_stat_current_%s", stat_bar_names[i]);
-        stat_current[i] = glade_xml_get_widget(xml_tree, buf);
-        snprintf(buf, sizeof(buf), "label_stat_max_%s", stat_bar_names[i]);
-        stat_max[i] = glade_xml_get_widget(xml_tree, buf);
-
         snprintf(buf, sizeof(buf), "progressbar_%s", stat_bar_names[i]);
-        stat_bar[i] = glade_xml_get_widget(xml_tree, buf);
+        stat_bar[i] = GTK_WIDGET(gtk_builder_get_object(window_xml, buf));
 
         lastval[i] = -1;
         lastmax[i] = -1;
     }
 
     statwindow.playername =
-        glade_xml_get_widget(xml_tree, "label_playername");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_playername"));
     statwindow.Str =
-        glade_xml_get_widget(xml_tree, "label_str");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_str"));
     statwindow.Dex =
-        glade_xml_get_widget(xml_tree, "label_dex");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_dex"));
     statwindow.Con =
-        glade_xml_get_widget(xml_tree, "label_con");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_con"));
     statwindow.Int =
-        glade_xml_get_widget(xml_tree, "label_int");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_int"));
     statwindow.Wis =
-        glade_xml_get_widget(xml_tree, "label_wis");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_wis"));
     statwindow.Pow =
-        glade_xml_get_widget(xml_tree, "label_pow");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_pow"));
     statwindow.Cha =
-        glade_xml_get_widget(xml_tree, "label_cha");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_cha"));
     statwindow.wc =
-        glade_xml_get_widget(xml_tree, "label_wc");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_wc"));
     statwindow.dam =
-        glade_xml_get_widget(xml_tree, "label_dam");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_dam"));
     statwindow.ac =
-        glade_xml_get_widget(xml_tree, "label_ac");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_ac"));
     statwindow.armor =
-        glade_xml_get_widget(xml_tree, "label_armor");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_armor"));
     statwindow.speed =
-        glade_xml_get_widget(xml_tree, "label_speed");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_speed"));
     statwindow.weapon_speed =
-        glade_xml_get_widget(xml_tree, "label_weapon_speed");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_weapon_speed"));
     statwindow.range =
-        glade_xml_get_widget(xml_tree, "label_range");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_range"));
     statwindow.exp =
-        glade_xml_get_widget(xml_tree, "label_exp");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_exp"));
     statwindow.level =
-        glade_xml_get_widget(xml_tree, "label_level");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "label_level"));
 
     /* Note that the order the labels are attached to the tables determines
      * the order of display.  The order as right now is left to right,
@@ -222,16 +198,16 @@ void stats_init(GtkWidget *window_root)
      */
 
     statwindow.table_skills_exp =
-        glade_xml_get_widget(xml_tree,"table_skills_exp");
+        GTK_WIDGET(gtk_builder_get_object(window_xml,"table_skills_exp"));
 
     if (statwindow.table_skills_exp) {
         /* Do not attempt to set up the table_skills_exp widget if it was not
-         * defined in the .glade layout.
+         * defined in the layout.
          */
         for (i=0, x=0, y=0; i < SKILL_BOXES_X * SKILL_BOXES_Y; i++) {
             statwindow.skill_exp[i] = gtk_label_new("");
             gtk_table_attach(GTK_TABLE(statwindow.table_skills_exp), statwindow.skill_exp[i],
-                      x, x+1, y, y+1, GTK_EXPAND, 0, 0, 0);
+                             x, x+1, y, y+1, GTK_EXPAND, 0, 0, 0);
             gtk_widget_show(statwindow.skill_exp[i]);
             x++;
             if (x == SKILL_BOXES_X) {
@@ -242,12 +218,12 @@ void stats_init(GtkWidget *window_root)
     }
 
     statwindow.table_protections =
-        glade_xml_get_widget(xml_tree,"table_protections");
+        GTK_WIDGET(gtk_builder_get_object(window_xml, "table_protections"));
 
     for (i=0, x=0, y=0; i < PROTECTION_BOXES_X * PROTECTION_BOXES_Y; i++) {
         statwindow.resists[i] = gtk_label_new("");
         gtk_table_attach(GTK_TABLE(statwindow.table_protections), statwindow.resists[i],
-                  x, x+1, y, y+1, GTK_EXPAND, 0, 0, 0);
+                         x, x+1, y, y+1, GTK_EXPAND, 0, 0, 0);
         gtk_widget_show(statwindow.resists[i]);
         x++;
         if (x == PROTECTION_BOXES_X) {
@@ -258,6 +234,37 @@ void stats_init(GtkWidget *window_root)
     /*stats_get_styles();*/
 }
 
+/**
+ * Format an integer using an appropriate SI prefix.
+ *
+ * @param number Number to format
+ * @return A newly-allocated string with the formatted number
+ */
+static char *format_si_number(gint64 number) {
+    /* List of SI prefixes and corresponding values, least to greatest. */
+    const char SI_SUFFIX[] = {'\0', 'k', 'M', 'G'};
+    const float SI_VALUE[] = {1, 1000, 1000000, 1000000000};
+
+    int suffix = 0, i;
+    float value;
+
+    /* Determine the most appropriate SI prefix to use. */
+    for (i = sizeof(SI_SUFFIX) / sizeof(char) - 1; i > 0; i--) {
+        if (number / SI_VALUE[i] >= 10) {
+            suffix = i;
+            break;
+        }
+    }
+
+    value = number / SI_VALUE[suffix];
+
+    /* If possible, trim the trailing zero decimal. */
+    if (value - (int)value == 0) {
+        return g_strdup_printf("%.0f%c", value, SI_SUFFIX[suffix]);
+    } else {
+        return g_strdup_printf("%.1f%c", value, SI_SUFFIX[suffix]);
+    }
+}
 
 /**
  * Updates the stat bar and text display as it pertains to a specific stat.
@@ -281,27 +288,25 @@ void stats_init(GtkWidget *window_root)
  * a stat shouldn't ever change color when it is low, the style should
  * dictate that.
  */
-void update_stat(int stat_no, sint64 max_stat, sint64 current_stat,
-         sint64 statbar_max, sint64 statbar_stat, int can_alert)
+void update_stat(int stat_no, gint64 max_stat, gint64 current_stat,
+                 gint64 statbar_max, gint64 statbar_stat, int can_alert)
 {
     float bar;
-    int is_alert;
-    char buf[256];
     GdkColor ncolor, *set_color=NULL;
 
     /* If nothing changed, don't need to do anything */
-    if (lastval[stat_no] == current_stat && lastmax[stat_no] == max_stat)
+    if (lastval[stat_no] == current_stat && lastmax[stat_no] == max_stat) {
         return;
+    }
 
     lastval[stat_no] = current_stat;
     lastmax[stat_no] = max_stat;
 
-    if (statbar_max > 0) bar = (float) statbar_stat / (float) statbar_max;
-    else bar = 0.0;
-
-    /* Simple check to see if current stat is less than 25% */
-    if (can_alert && current_stat * 4 < max_stat) is_alert=1;
-    else is_alert = 0;
+    if (statbar_max > 0) {
+        bar = (float) statbar_stat / (float) statbar_max;
+    } else {
+        bar = 0.0;
+    }
 
     if (use_config[CONFIG_GRAD_COLOR]) {
         /* In this mode, the color of the stat bar were go between red and green
@@ -317,12 +322,16 @@ void update_stat(int stat_no, sint64 max_stat, sint64 current_stat,
          * blending logic below is the same regardless of actual value.
          */
         if (bar > 1.0) {
-            if (bar>2.0) bar=2.0;  /* Display unaffected; just calculations */
+            if (bar>2.0) {
+                bar=2.0;    /* Display unaffected; just calculations */
+            }
             hcolor = bar_colors[stat_no][STYLE_GRAD_SUPER];
             lcolor = bar_colors[stat_no][STYLE_GRAD_NORMAL];
             diff = bar - 1.0;
         } else {
-            if (bar < 0.0) bar=0.0;  /* Like above, does not affect display */
+            if (bar < 0.0) {
+                bar=0.0;    /* Like above, does not affect display */
+            }
             hcolor = bar_colors[stat_no][STYLE_GRAD_NORMAL];
             lcolor = bar_colors[stat_no][STYLE_GRAD_LOW];
             diff = bar;
@@ -363,26 +372,32 @@ void update_stat(int stat_no, sint64 max_stat, sint64 current_stat,
             if (diff > 0.5) {
                 memcpy(&ncolor, hcolor, sizeof(GdkColor));
 
-                if (lcolor->red > hcolor->red)
+                if (lcolor->red > hcolor->red) {
                     ncolor.red = 2 * lcolor->red * (1.0 - diff);
+                }
 
-                if (lcolor->green > hcolor->green)
+                if (lcolor->green > hcolor->green) {
                     ncolor.green = 2 * lcolor->green * (1.0 - diff);
+                }
 
-                if (lcolor->blue > hcolor->blue)
+                if (lcolor->blue > hcolor->blue) {
                     ncolor.blue = 2 * lcolor->blue * (1.0 - diff);
+                }
 
             } else {
                 memcpy(&ncolor, lcolor, sizeof(GdkColor));
 
-                if (hcolor->red > lcolor->red)
+                if (hcolor->red > lcolor->red) {
                     ncolor.red = 2 * hcolor->red * diff;
+                }
 
-                if (hcolor->green > lcolor->green)
+                if (hcolor->green > lcolor->green) {
                     ncolor.green = 2 * hcolor->green * diff;
+                }
 
-                if (hcolor->blue > lcolor->blue)
+                if (hcolor->blue > lcolor->blue) {
                     ncolor.blue = 2 * hcolor->blue * diff;
+                }
             }
 #endif
 #if 0
@@ -392,27 +407,48 @@ void update_stat(int stat_no, sint64 max_stat, sint64 current_stat,
             set_color = &ncolor;
         }
     } else {
-        if (statbar_stat * 4 < statbar_max)
+        if (statbar_stat * 4 < statbar_max) {
             set_color = bar_colors[stat_no][STYLE_LOW];
-        else if (statbar_stat > statbar_max)
+        } else if (statbar_stat > statbar_max) {
             set_color = bar_colors[stat_no][STYLE_SUPER];
-        else
+        } else {
             set_color = bar_colors[stat_no][STYLE_NORMAL];
+        }
     }
-    if (bar > 1.0) bar = 1.0;
-    if (bar < 0.0) bar = 0.0;
+    if (bar > 1.0) {
+        bar = 1.0;
+    }
+    if (bar < 0.0) {
+        bar = 0.0;
+    }
+
+    GtkProgressBar *curr_bar = GTK_PROGRESS_BAR(stat_bar[stat_no]);
 
     /* It may be a waste, but we set the color everytime here - it isn't very
      * costly, and keeps us from tracing the last color we set.  Note that
      * set_color could be null, which means it reverts back to normal color.
      */
     gtk_widget_modify_base(stat_bar[stat_no], GTK_STATE_SELECTED, set_color);
-    gtk_progress_set_percentage(GTK_PROGRESS(stat_bar[stat_no]), bar);
+    /* The line above doesn't work sometimes, but then, the next one does. */
+    gtk_widget_modify_bg(stat_bar[stat_no], GTK_STATE_PRELIGHT, set_color);
 
-    snprintf(buf, sizeof(buf), "%"FMT64, current_stat);
-    gtk_label_set(GTK_LABEL(stat_current[stat_no]), buf);
-    snprintf(buf, sizeof(buf), "%"FMT64, max_stat);
-    gtk_label_set(GTK_LABEL(stat_max[stat_no]), buf);
+    char *label;
+
+    // Display experience using SI prefixes; everything else normally.
+    if (stat_no == STAT_BAR_EXP) {
+        char *exp_curr = format_si_number(current_stat);
+        char *exp_max = format_si_number(max_stat);
+        label = g_strdup_printf("%s/%s", exp_curr, exp_max);
+        g_free(exp_curr);
+        g_free(exp_max);
+    } else {
+        label = g_strdup_printf("%" G_GINT64_FORMAT "/%" G_GINT64_FORMAT,
+                current_stat, max_stat);
+    }
+
+    gtk_progress_bar_set_fraction(curr_bar, bar);
+    gtk_progress_bar_set_text(curr_bar, label);
+    g_free(label);
 }
 
 /**
@@ -420,17 +456,18 @@ void update_stat(int stat_no, sint64 max_stat, sint64 current_stat,
  *
  * @param redraw
  */
-void draw_message_window(int redraw) {
+void draw_message_window(int redraw)
+{
     static int lastbeep=0;
-    static sint64 level_diff;
+    static gint64 level_diff;
 
-    update_stat(0, cpl.stats.maxhp, cpl.stats.hp,
+    update_stat(STAT_BAR_HP, cpl.stats.maxhp, cpl.stats.hp,
                 cpl.stats.maxhp, cpl.stats.hp, TRUE);
-    update_stat(1, cpl.stats.maxsp, cpl.stats.sp,
+    update_stat(STAT_BAR_SP, cpl.stats.maxsp, cpl.stats.sp,
                 cpl.stats.maxsp, cpl.stats.sp, TRUE);
-    update_stat(2, cpl.stats.maxgrace, cpl.stats.grace,
+    update_stat(STAT_BAR_GRACE, cpl.stats.maxgrace, cpl.stats.grace,
                 cpl.stats.maxgrace, cpl.stats.grace, TRUE);
-    update_stat(3, 999, cpl.stats.food, 999, cpl.stats.food, TRUE);
+    update_stat(STAT_BAR_FOOD, 999, cpl.stats.food, 999, cpl.stats.food, TRUE);
 
     /* We may or may not have an exp table from the server.  If we don't, just
      * use current exp value so it will always appear maxed out.
@@ -438,16 +475,17 @@ void draw_message_window(int redraw) {
     /* We calculate level_diff here just so it makes the update_stat()
      * call below less messy.
      */
-    if ((cpl.stats.level+1) < exp_table_max)
+    if ((cpl.stats.level+1) < exp_table_max) {
         level_diff = exp_table[cpl.stats.level+1] - exp_table[cpl.stats.level];
-    else
+    } else {
         level_diff=cpl.stats.exp;
+    }
 
-    update_stat(4,
-        (cpl.stats.level+1) < exp_table_max ? exp_table[cpl.stats.level+1]:cpl.stats.exp,
-        cpl.stats.exp,
-        level_diff,
-        (cpl.stats.level+1) < exp_table_max ?
+    update_stat(STAT_BAR_EXP,
+                (cpl.stats.level+1) < exp_table_max ? exp_table[cpl.stats.level+1]:cpl.stats.exp,
+                cpl.stats.exp,
+                level_diff,
+                (cpl.stats.level+1) < exp_table_max ?
                 (cpl.stats.exp - exp_table[cpl.stats.level]):cpl.stats.exp, FALSE);
 
     if (use_config[CONFIG_FOODBEEP] && (cpl.stats.food%4==3) && (cpl.stats.food < 200)) {
@@ -464,10 +502,17 @@ void draw_message_window(int redraw) {
  */
 static int mapping_sort(NameMapping *a, NameMapping *b)
 {
-    if (!a->name && !b->name) return 0;
-    if (!a->name) return 1;
-    if (!b->name) return -1;
-    else return strcasecmp(a->name, b->name);
+    if (!a->name && !b->name) {
+        return 0;
+    }
+    if (!a->name) {
+        return 1;
+    }
+    if (!b->name) {
+        return -1;
+    } else {
+        return g_ascii_strcasecmp(a->name, b->name);
+    }
 }
 
 /**
@@ -479,32 +524,35 @@ static void update_stat_mapping(void)
 
     for (i=0; i < MAX_SKILL; i++) {
         skill_mapping[i].value=i;
-        if (skill_names[i])
+        if (skill_names[i]) {
             skill_mapping[i].name = skill_names[i];
-        else
+        } else {
             skill_mapping[i].name = NULL;
+        }
     }
     qsort(skill_mapping, MAX_SKILL, sizeof(NameMapping),
           (int (*)(const void*, const void*))mapping_sort);
 
     for (i=0; i < NUM_RESISTS; i++) {
         resist_mapping[i].value=i;
-        if (resists_name[i])
+        if (resists_name[i]) {
             resist_mapping[i].name = resists_name[i];
-        else
+        } else {
             resist_mapping[i].name = NULL;
+        }
     }
     qsort(resist_mapping, NUM_RESISTS, sizeof(NameMapping),
           (int (*)(const void*, const void*))mapping_sort);
 
-    need_mapping_update=0;
+    need_mapping_update = FALSE;
 }
 
 /**
  * Draws the stats window.  If redraw is true, it means we need to redraw the
  * entire thing, and not just do an updated
  */
-void draw_stats(int redraw) {
+void draw_stats(int redraw)
+{
     static Stats last_stats;
     static char last_name[MAX_BUF]="", last_range[MAX_BUF]="";
     static int init_before=0, max_drawn_skill=0, max_drawn_resists=0;
@@ -528,118 +576,121 @@ void draw_stats(int redraw) {
     }
 
     if (strcmp(cpl.title, last_name) || redraw) {
-        strcpy(last_name,cpl.title);
-        gtk_label_set (GTK_LABEL(statwindow.playername), cpl.title);
+        strcpy(last_name, cpl.title);
+        gtk_label_set_text(GTK_LABEL(statwindow.playername), cpl.title);
     }
 
-    if(redraw || cpl.stats.exp!=last_stats.exp) {
+    if (redraw || cpl.stats.exp != last_stats.exp) {
         last_stats.exp = cpl.stats.exp;
-        snprintf(buff, sizeof(buff), "Experience: %5" FMT64 ,cpl.stats.exp);
-        gtk_label_set (GTK_LABEL(statwindow.exp), buff);
+        snprintf(buff, sizeof(buff), "Experience: %5" G_GINT64_FORMAT,
+                 cpl.stats.exp);
+        gtk_label_set_text(GTK_LABEL(statwindow.exp), buff);
     }
 
-    if(redraw || cpl.stats.level!=last_stats.level) {
+    if (redraw || cpl.stats.level != last_stats.level) {
         last_stats.level = cpl.stats.level;
-        snprintf(buff, sizeof(buff), "Level: %d",cpl.stats.level);
-        gtk_label_set (GTK_LABEL(statwindow.level), buff);
+        snprintf(buff, sizeof(buff), "Level: %d", cpl.stats.level);
+        gtk_label_set_text(GTK_LABEL(statwindow.level), buff);
     }
 
-    if(redraw || cpl.stats.Str!=last_stats.Str) {
-        last_stats.Str=cpl.stats.Str;
-        snprintf(buff, sizeof(buff), "%2d",cpl.stats.Str);
-        gtk_label_set (GTK_LABEL(statwindow.Str), buff);
+    if (redraw || cpl.stats.Str != last_stats.Str) {
+        last_stats.Str = cpl.stats.Str;
+        snprintf(buff, sizeof(buff), "%2d", cpl.stats.Str);
+        gtk_label_set_text(GTK_LABEL(statwindow.Str), buff);
     }
 
-    if(redraw || cpl.stats.Dex!=last_stats.Dex) {
-        last_stats.Dex=cpl.stats.Dex;
-        snprintf(buff, sizeof(buff), "%2d",cpl.stats.Dex);
-        gtk_label_set (GTK_LABEL(statwindow.Dex), buff);
+    if (redraw || cpl.stats.Dex != last_stats.Dex) {
+        last_stats.Dex = cpl.stats.Dex;
+        snprintf(buff, sizeof(buff), "%2d", cpl.stats.Dex);
+        gtk_label_set_text(GTK_LABEL(statwindow.Dex), buff);
     }
 
-    if(redraw || cpl.stats.Con!=last_stats.Con) {
-        last_stats.Con=cpl.stats.Con;
-        snprintf(buff, sizeof(buff), "%2d",cpl.stats.Con);
-        gtk_label_set (GTK_LABEL(statwindow.Con), buff);
+    if (redraw || cpl.stats.Con != last_stats.Con) {
+        last_stats.Con = cpl.stats.Con;
+        snprintf(buff, sizeof(buff), "%2d", cpl.stats.Con);
+        gtk_label_set_text(GTK_LABEL(statwindow.Con), buff);
     }
 
-    if(redraw || cpl.stats.Int!=last_stats.Int) {
-        last_stats.Int=cpl.stats.Int;
-        snprintf(buff, sizeof(buff), "%2d",cpl.stats.Int);
-        gtk_label_set (GTK_LABEL(statwindow.Int), buff);
+    if (redraw || cpl.stats.Int != last_stats.Int) {
+        last_stats.Int = cpl.stats.Int;
+        snprintf(buff, sizeof(buff), "%2d", cpl.stats.Int);
+        gtk_label_set_text(GTK_LABEL(statwindow.Int), buff);
     }
 
-    if(redraw || cpl.stats.Wis!=last_stats.Wis) {
-        last_stats.Wis=cpl.stats.Wis;
-        snprintf(buff, sizeof(buff), "%2d",cpl.stats.Wis);
-        gtk_label_set (GTK_LABEL(statwindow.Wis), buff);
+    if (redraw || cpl.stats.Wis != last_stats.Wis) {
+        last_stats.Wis = cpl.stats.Wis;
+        snprintf(buff, sizeof(buff), "%2d", cpl.stats.Wis);
+        gtk_label_set_text(GTK_LABEL(statwindow.Wis), buff);
     }
 
-    if(redraw || cpl.stats.Pow!=last_stats.Pow) {
-        last_stats.Pow=cpl.stats.Pow;
-        snprintf(buff, sizeof(buff), "%2d",cpl.stats.Pow);
-        gtk_label_set (GTK_LABEL(statwindow.Pow), buff);
+    if (redraw || cpl.stats.Pow != last_stats.Pow) {
+        last_stats.Pow = cpl.stats.Pow;
+        snprintf(buff, sizeof(buff), "%2d", cpl.stats.Pow);
+        gtk_label_set_text(GTK_LABEL(statwindow.Pow), buff);
     }
 
-    if(redraw || cpl.stats.Cha!=last_stats.Cha) {
-        last_stats.Cha=cpl.stats.Cha;
-        snprintf(buff, sizeof(buff), "%2d",cpl.stats.Cha);
-        gtk_label_set (GTK_LABEL(statwindow.Cha), buff);
+    if (redraw || cpl.stats.Cha != last_stats.Cha) {
+        last_stats.Cha = cpl.stats.Cha;
+        snprintf(buff, sizeof(buff), "%2d", cpl.stats.Cha);
+        gtk_label_set_text(GTK_LABEL(statwindow.Cha), buff);
     }
 
-    if(redraw || cpl.stats.wc!=last_stats.wc) {
-        last_stats.wc=cpl.stats.wc;
-        snprintf(buff, sizeof(buff), "%3d",cpl.stats.wc);
-        gtk_label_set (GTK_LABEL(statwindow.wc), buff);
+    if (redraw || cpl.stats.wc != last_stats.wc) {
+        last_stats.wc = cpl.stats.wc;
+        snprintf(buff, sizeof(buff), "%2d", cpl.stats.wc);
+        gtk_label_set_text(GTK_LABEL(statwindow.wc), buff);
     }
 
-    if(redraw || cpl.stats.dam!=last_stats.dam) {
-        last_stats.dam=cpl.stats.dam;
-        snprintf(buff, sizeof(buff), "%d",cpl.stats.dam);
-        gtk_label_set (GTK_LABEL(statwindow.dam), buff);
+    if (redraw || cpl.stats.dam != last_stats.dam) {
+        last_stats.dam = cpl.stats.dam;
+        snprintf(buff, sizeof(buff), "%d", cpl.stats.dam);
+        gtk_label_set_text(GTK_LABEL(statwindow.dam), buff);
     }
 
-    if(redraw || cpl.stats.ac!=last_stats.ac) {
-        last_stats.ac=cpl.stats.ac;
-        snprintf(buff, sizeof(buff), "%d",cpl.stats.ac);
-        gtk_label_set (GTK_LABEL(statwindow.ac), buff);
+    if (redraw || cpl.stats.ac != last_stats.ac) {
+        last_stats.ac = cpl.stats.ac;
+        snprintf(buff, sizeof(buff), "%d", cpl.stats.ac);
+        gtk_label_set_text(GTK_LABEL(statwindow.ac), buff);
     }
 
-    if(redraw || cpl.stats.resists[0]!=last_stats.resists[0]) {
-        last_stats.resists[0]=cpl.stats.resists[0];
-        snprintf(buff, sizeof(buff), "%d",cpl.stats.resists[0]);
-        gtk_label_set (GTK_LABEL(statwindow.armor), buff);
+    if (redraw || cpl.stats.resists[0] != last_stats.resists[0]) {
+        last_stats.resists[0] = cpl.stats.resists[0];
+        snprintf(buff, sizeof(buff), "%d", cpl.stats.resists[0]);
+        gtk_label_set_text(GTK_LABEL(statwindow.armor), buff);
     }
 
-    if (redraw || cpl.stats.speed!=last_stats.speed) {
-        last_stats.speed=cpl.stats.speed;
-        snprintf(buff, sizeof(buff), "%3.2f",(float)cpl.stats.speed/FLOAT_MULTF);
-        gtk_label_set (GTK_LABEL(statwindow.speed), buff);
+    if (redraw || cpl.stats.speed != last_stats.speed) {
+        last_stats.speed = cpl.stats.speed;
+        snprintf(buff, sizeof(buff), "%3.2f",
+                 (float)cpl.stats.speed / FLOAT_MULTF);
+        gtk_label_set_text(GTK_LABEL(statwindow.speed), buff);
     }
     /* sc_version >= 1029 reports real value of weapon speed -
      * not as a factor of player speed.  Handle accordingly.
      */
-    if (csocket.sc_version >= 1029)
-        weap_sp = (float) cpl.stats.weapon_sp / FLOAT_MULTF;
-    else
-        weap_sp = (float) cpl.stats.speed/((float)cpl.stats.weapon_sp);
-
-    if (redraw || weap_sp !=last_stats.weapon_sp) {
-        last_stats.weapon_sp=weap_sp;
-        snprintf(buff, sizeof(buff), "%3.2f",weap_sp);
-        gtk_label_set (GTK_LABEL(statwindow.weapon_speed), buff);
+    if (csocket.sc_version >= 1029) {
+        weap_sp = (float)cpl.stats.weapon_sp / FLOAT_MULTF;
+    } else {
+        weap_sp = (float)cpl.stats.speed / ((float)cpl.stats.weapon_sp);
     }
 
-    if(redraw || strcmp(cpl.range, last_range)) {
+    if (redraw || weap_sp != last_stats.weapon_sp) {
+        last_stats.weapon_sp = weap_sp;
+        snprintf(buff, sizeof(buff), "%3.2f", weap_sp);
+        gtk_label_set_text(GTK_LABEL(statwindow.weapon_speed), buff);
+    }
+
+    if (redraw || strcmp(cpl.range, last_range)) {
         strcpy(last_range, cpl.range);
-        snprintf(buff, sizeof(buff), "Range: %s",cpl.range);
-        gtk_label_set (GTK_LABEL(statwindow.range), cpl.range);
+        snprintf(buff, sizeof(buff), "Range: %s", cpl.range);
+        gtk_label_set_text(GTK_LABEL(statwindow.range), cpl.range);
     }
 
     update_skill_information();
 
     if (statwindow.table_skills_exp) {
         /* Do not attempt to set up the table_skills_exp widget if it was not
-         * defined in the .glade layout.
+         * defined in the layout.
          */
         on_skill=0;
         assert(sizeof(statwindow.skill_exp)/sizeof(*statwindow.skill_exp) >= 2*MAX_SKILL);
@@ -652,12 +703,12 @@ void draw_stats(int redraw) {
             sk = skill_mapping[i].value;
 
             if ((redraw || cpl.stats.skill_exp[sk] != last_stats.skill_exp[sk])
-            && skill_mapping[i].name && cpl.stats.skill_exp[sk]) {
-                gtk_label_set(GTK_LABEL(statwindow.skill_exp[on_skill++]),
-                    skill_mapping[i].name);
-                snprintf(buff, sizeof(buff), "%" FMT64 " (%d)",
-                    cpl.stats.skill_exp[sk], cpl.stats.skill_level[sk]);
-                gtk_label_set(
+                    && skill_mapping[i].name && cpl.stats.skill_exp[sk]) {
+                gtk_label_set_text(GTK_LABEL(statwindow.skill_exp[on_skill++]),
+                              skill_mapping[i].name);
+                snprintf(buff, sizeof(buff), "%" G_GINT64_FORMAT " (%d)",
+                         cpl.stats.skill_exp[sk], cpl.stats.skill_level[sk]);
+                gtk_label_set_text(
                     GTK_LABEL(statwindow.skill_exp[on_skill++]), buff);
                 last_stats.skill_level[sk] = cpl.stats.skill_level[sk];
                 last_stats.skill_exp[sk] = cpl.stats.skill_exp[sk];
@@ -675,34 +726,36 @@ void draw_stats(int redraw) {
          * extra.
          */
         if (on_skill < max_drawn_skill) {
-            int k;
-
-            for (k = on_skill; k <= max_drawn_skill; k++)
-                gtk_label_set(GTK_LABEL(statwindow.skill_exp[k]), "");
+            for (int k = on_skill; k <= max_drawn_skill; k++) {
+                gtk_label_set_text(GTK_LABEL(statwindow.skill_exp[k]), "");
+            }
         }
         max_drawn_skill = on_skill;
     }
 
     /* Now do the resistance table */
     if (redraw || cpl.stats.resist_change) {
-        int i,j=0;
+        int j = 0;
 
         cpl.stats.resist_change=0;
-        for (i=0; i<NUM_RESISTS; i++) {
+        for (int i = 0; i < NUM_RESISTS; i++) {
             sk = resist_mapping[i].value;
             if (cpl.stats.resists[sk]) {
-                gtk_label_set(GTK_LABEL(statwindow.resists[j]), resist_mapping[i].name);
+                gtk_label_set_text(GTK_LABEL(statwindow.resists[j]),
+                                   resist_mapping[i].name);
                 j++;
                 snprintf(buff, sizeof(buff), "%+4d", cpl.stats.resists[sk]);
-                gtk_label_set(GTK_LABEL(statwindow.resists[j]), buff);
+                gtk_label_set_text(GTK_LABEL(statwindow.resists[j]), buff);
                 j++;
-                if (j >= PROTECTION_BOXES_X * PROTECTION_BOXES_Y) break;
+                if (j >= PROTECTION_BOXES_X * PROTECTION_BOXES_Y) {
+                    break;
+                }
             }
         }
         /* Erase old/unused resistances */
         if (j < max_drawn_resists) {
-            for (i=j; i <= max_drawn_resists; i++)  {
-                gtk_label_set(GTK_LABEL(statwindow.resists[i]), "");
+            for (int i = j; i <= max_drawn_resists; i++) {
+                gtk_label_set_text(GTK_LABEL(statwindow.resists[i]), "");
             }
         }
         max_drawn_resists = j;
@@ -715,10 +768,6 @@ void draw_stats(int redraw) {
 
 }
 
-/**
- *
- */
-void clear_stat_mapping(void)
-{
-    need_mapping_update=1;
+void clear_stat_mapping() {
+    need_mapping_update = TRUE;
 }
